Class: Aws::BedrockAgent::Types::BedrockEmbeddingModelConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

The vector configuration details for the Bedrock embeddings model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audioArray<Types::AudioConfiguration>

Configuration settings for processing audio content in multimodal knowledge bases.

This field is deprecated. Use modelConfiguration instead.

Returns:



1328
1329
1330
1331
1332
1333
1334
1335
1336
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video,
  :model_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#dimensionsInteger

The dimensions details for the vector configuration used on the Bedrock embeddings model.

Returns:



1328
1329
1330
1331
1332
1333
1334
1335
1336
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video,
  :model_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#embedding_data_typeString

The data type for the vectors when using a model to convert text into vector embeddings. The model must support the specified data type for vector embeddings. Floating-point (float32) is the default data type, and is supported by most models for vector embeddings. See Supported embeddings models for information on the available models and their vector data types.

Returns:



1328
1329
1330
1331
1332
1333
1334
1335
1336
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video,
  :model_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#model_configurationHash, ...

Model-specific configuration for the embedding model, provided as a JSON object. Use this field to specify settings that apply to the embedding model that you selected, such as how audio and video files are divided into segments.

The fields that this object accepts depend on the embedding model. For the settings that each model accepts, see the documentation for that model.

Returns:



1328
1329
1330
1331
1332
1333
1334
1335
1336
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video,
  :model_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#videoArray<Types::VideoConfiguration>

Configuration settings for processing video content in multimodal knowledge bases.

This field is deprecated. Use modelConfiguration instead.

Returns:



1328
1329
1330
1331
1332
1333
1334
1335
1336
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video,
  :model_configuration)
  SENSITIVE = []
  include Aws::Structure
end