Class: Aws::BedrockAgent::Types::ConfluenceDataSourceConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ConfluenceDataSourceConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
The configuration information to connect to Confluence as your data source for self-managed knowledge bases.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#crawler_configuration ⇒ Types::ConfluenceCrawlerConfiguration
The configuration of the Confluence content.
-
#source_configuration ⇒ Types::ConfluenceSourceConfiguration
The endpoint information to connect to your Confluence data source.
Instance Attribute Details
#crawler_configuration ⇒ Types::ConfluenceCrawlerConfiguration
The configuration of the Confluence content. For example, configuring specific types of Confluence content.
1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1641 class ConfluenceDataSourceConfiguration < Struct.new( :source_configuration, :crawler_configuration) SENSITIVE = [] include Aws::Structure end |
#source_configuration ⇒ Types::ConfluenceSourceConfiguration
The endpoint information to connect to your Confluence data source.
1641 1642 1643 1644 1645 1646 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1641 class ConfluenceDataSourceConfiguration < Struct.new( :source_configuration, :crawler_configuration) SENSITIVE = [] include Aws::Structure end |