Class: Aws::BedrockAgent::Types::ContentBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ContentBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Note:
ContentBlock is a union - when making an API calls you must set exactly one of the members.
Note:
ContentBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ContentBlock corresponding to the set member.
Contains the content for the message you pass to, or receive from a model. For more information, see Create a prompt using Prompt management.
Defined Under Namespace
Classes: CachePoint, Text, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_point ⇒ Types::CachePointBlock
Creates a cache checkpoint within a message.
-
#text ⇒ String
The text in the message.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#cache_point ⇒ Types::CachePointBlock
Creates a cache checkpoint within a message.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1708 class ContentBlock < Struct.new( :text, :cache_point, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class CachePoint < ContentBlock; end class Unknown < ContentBlock; end end |
#text ⇒ String
The text in the message.
1708 1709 1710 1711 1712 1713 1714 1715 1716 1717 1718 1719 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1708 class ContentBlock < Struct.new( :text, :cache_point, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < ContentBlock; end class CachePoint < ContentBlock; end class Unknown < ContentBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
1708 1709 1710 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1708 def unknown @unknown end |