Class: Aws::BedrockAgent::Types::ContextEnrichmentConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ContextEnrichmentConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Context enrichment configuration is used to provide additional context to the RAG application.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#bedrock_foundation_model_configuration ⇒ Types::BedrockFoundationModelContextEnrichmentConfiguration
The configuration of the Amazon Bedrock foundation model used for context enrichment.
-
#type ⇒ String
The method used for context enrichment.
Instance Attribute Details
#bedrock_foundation_model_configuration ⇒ Types::BedrockFoundationModelContextEnrichmentConfiguration
The configuration of the Amazon Bedrock foundation model used for context enrichment.
1720 1721 1722 1723 1724 1725 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1720 class ContextEnrichmentConfiguration < Struct.new( :type, :bedrock_foundation_model_configuration) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The method used for context enrichment. It must be Amazon Bedrock foundation models.
1720 1721 1722 1723 1724 1725 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1720 class ContextEnrichmentConfiguration < Struct.new( :type, :bedrock_foundation_model_configuration) SENSITIVE = [] include Aws::Structure end |