Class: Aws::BedrockAgent::Types::CreateAgentActionGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_group_executorTypes::ActionGroupExecutor

The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action or the custom control method for handling the information elicited from the user.



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#action_group_nameString

The name to give the action group.

Returns:

  • (String)


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#action_group_stateString

Specifies whether the action group is available for the agent to invoke or not when sending an InvokeAgent request.

Returns:

  • (String)


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#agent_idString

The unique identifier of the agent for which to create the action group.

Returns:

  • (String)


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#agent_versionString

The version of the agent for which to create the action group.

Returns:

  • (String)


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#api_schemaTypes::APISchema

Contains either details about the S3 object containing the OpenAPI schema for the action group or the JSON or YAML-formatted payload defining the schema. For more information, see Action group OpenAPI schemas.

Returns:



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#client_tokenString

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the action group.

Returns:

  • (String)


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#function_schemaTypes::FunctionSchema

Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.



1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#parent_action_group_signatureString

Specify a built-in or computer use action for this action group. If you specify a value, you must leave the description, apiSchema, and actionGroupExecutor fields empty for this action group.

  • To allow your agent to request the user for additional information when trying to complete a task, set this field to AMAZON.UserInput.

  • To allow your agent to generate, run, and troubleshoot code when trying to complete a task, set this field to AMAZON.CodeInterpreter.

  • To allow your agent to use an Anthropic computer use tool, specify one of the following values.

    Computer use is a new Anthropic Claude model capability (in beta) available with Anthropic Claude 3.7 Sonnet and Claude 3.5 Sonnet v2 only. When operating computer use functionality, we recommend taking additional security precautions, such as executing computer actions in virtual environments with restricted data access and limited internet connectivity. For more information, see Configure an Amazon Bedrock Agent to complete tasks with computer use tools.

  • ANTHROPIC.Computer - Gives the agent permission to use the mouse and keyboard and take screenshots.

  • ANTHROPIC.TextEditor - Gives the agent permission to view, create and edit files.

  • ANTHROPIC.Bash - Gives the agent permission to run commands in a bash shell.

Returns:

  • (String)


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end

#parent_action_group_signature_paramsHash<String,String>

The configuration settings for a computer use action.

Computer use is a new Anthropic Claude model capability (in beta) available with Anthropic Claude 3.7 Sonnet and Claude 3.5 Sonnet v2 only. For more information, see Configure an Amazon Bedrock Agent to complete tasks with computer use tools.

Returns:

  • (Hash<String,String>)


1884
1885
1886
1887
1888
1889
1890
1891
1892
1893
1894
1895
1896
1897
1898
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1884

class CreateAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_name,
  :client_token,
  :description,
  :parent_action_group_signature,
  :parent_action_group_signature_params,
  :action_group_executor,
  :api_schema,
  :action_group_state,
  :function_schema)
  SENSITIVE = []
  include Aws::Structure
end