Class: Aws::BedrockAgent::Types::CreatePromptRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:variants]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2664

class CreatePromptRequest < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :client_token,
  :tags)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#customer_encryption_key_arnString

The Amazon Resource Name (ARN) of the KMS key to encrypt the prompt.

Returns:

  • (String)


2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2664

class CreatePromptRequest < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :client_token,
  :tags)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#default_variantString

The name of the default variant for the prompt. This value must match the name field in the relevant PromptVariant object.

Returns:

  • (String)


2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2664

class CreatePromptRequest < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :client_token,
  :tags)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#descriptionString

A description for the prompt.

Returns:

  • (String)


2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2664

class CreatePromptRequest < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :client_token,
  :tags)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#nameString

A name for the prompt.

Returns:

  • (String)


2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2664

class CreatePromptRequest < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :client_token,
  :tags)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#tagsHash<String,String>

Any tags that you want to attach to the prompt. For more information, see Tagging resources in Amazon Bedrock.

Returns:

  • (Hash<String,String>)


2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2664

class CreatePromptRequest < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :client_token,
  :tags)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#variantsArray<Types::PromptVariant>

A list of objects, each containing details about a variant of the prompt.

Returns:



2664
2665
2666
2667
2668
2669
2670
2671
2672
2673
2674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2664

class CreatePromptRequest < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :client_token,
  :tags)
  SENSITIVE = [:variants]
  include Aws::Structure
end