Class: Aws::BedrockAgent::Types::CreatePromptVersionResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:variants]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the version of the prompt.

Returns:

  • (String)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#created_atTime

The time at which the prompt was created.

Returns:

  • (Time)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#customer_encryption_key_arnString

The Amazon Resource Name (ARN) of the KMS key to encrypt the version of the prompt.

Returns:

  • (String)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#default_variantString

The name of the default variant for the prompt. This value must match the name field in the relevant PromptVariant object.

Returns:

  • (String)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#descriptionString

A description for the version.

Returns:

  • (String)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#idString

The unique identifier of the prompt.

Returns:

  • (String)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#nameString

The name of the prompt.

Returns:

  • (String)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#updated_atTime

The time at which the prompt was last updated.

Returns:

  • (Time)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#variantsArray<Types::PromptVariant>

A list of objects, each containing details about a variant of the prompt.

Returns:



2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end

#versionString

The version of the prompt that was created. Versions are numbered incrementally, starting from 1.

Returns:

  • (String)


2845
2846
2847
2848
2849
2850
2851
2852
2853
2854
2855
2856
2857
2858
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845

class CreatePromptVersionResponse < Struct.new(
  :name,
  :description,
  :customer_encryption_key_arn,
  :default_variant,
  :variants,
  :id,
  :arn,
  :version,
  :created_at,
  :updated_at)
  SENSITIVE = [:variants]
  include Aws::Structure
end