Class: Aws::BedrockAgent::Types::CuratedQuery

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains configurations for a query, each of which defines information about example queries to help the query engine generate appropriate SQL queries.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#natural_languageString

An example natural language query.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2874

class CuratedQuery < Struct.new(
  :natural_language,
  :sql)
  SENSITIVE = []
  include Aws::Structure
end

#sqlString

The SQL equivalent of the natural language query.

Returns:

  • (String)


2874
2875
2876
2877
2878
2879
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2874

class CuratedQuery < Struct.new(
  :natural_language,
  :sql)
  SENSITIVE = []
  include Aws::Structure
end