Class: Aws::BedrockAgent::Types::CustomDocumentIdentifier

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains information about the identifier of the document to ingest into a custom data source.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#idString

The identifier of the document to ingest into a custom data source.

Returns:

  • (String)


2907
2908
2909
2910
2911
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2907

class CustomDocumentIdentifier < Struct.new(
  :id)
  SENSITIVE = []
  include Aws::Structure
end