Class: Aws::BedrockAgent::Types::DeleteAgentActionGroupRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#action_group_idString

The unique identifier of the action group to delete.

Returns:

  • (String)


3285
3286
3287
3288
3289
3290
3291
3292
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3285

class DeleteAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#agent_idString

The unique identifier of the agent that the action group belongs to.

Returns:

  • (String)


3285
3286
3287
3288
3289
3290
3291
3292
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3285

class DeleteAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#agent_versionString

The version of the agent that the action group belongs to.

Returns:

  • (String)


3285
3286
3287
3288
3289
3290
3291
3292
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3285

class DeleteAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_resource_in_use_checkBoolean

By default, this value is false and deletion is stopped if the resource is in use. If you set it to true, the resource will be deleted even if the resource is in use.

Returns:

  • (Boolean)


3285
3286
3287
3288
3289
3290
3291
3292
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3285

class DeleteAgentActionGroupRequest < Struct.new(
  :agent_id,
  :agent_version,
  :action_group_id,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end