Class: Aws::BedrockAgent::Types::DeleteAgentAliasResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DeleteAgentAliasResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_alias_id ⇒ String
The unique identifier of the alias that was deleted.
-
#agent_alias_status ⇒ String
The status of the alias.
-
#agent_id ⇒ String
The unique identifier of the agent that the alias belongs to.
Instance Attribute Details
#agent_alias_id ⇒ String
The unique identifier of the alias that was deleted.
3329 3330 3331 3332 3333 3334 3335 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3329 class DeleteAgentAliasResponse < Struct.new( :agent_id, :agent_alias_id, :agent_alias_status) SENSITIVE = [] include Aws::Structure end |
#agent_alias_status ⇒ String
The status of the alias.
3329 3330 3331 3332 3333 3334 3335 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3329 class DeleteAgentAliasResponse < Struct.new( :agent_id, :agent_alias_id, :agent_alias_status) SENSITIVE = [] include Aws::Structure end |
#agent_id ⇒ String
The unique identifier of the agent that the alias belongs to.
3329 3330 3331 3332 3333 3334 3335 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3329 class DeleteAgentAliasResponse < Struct.new( :agent_id, :agent_alias_id, :agent_alias_status) SENSITIVE = [] include Aws::Structure end |