Class: Aws::BedrockAgent::Types::DeleteAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DeleteAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier of the agent to delete.
-
#skip_resource_in_use_check ⇒ Boolean
By default, this value is
falseand deletion is stopped if the resource is in use.
Instance Attribute Details
#agent_id ⇒ String
The unique identifier of the agent to delete.
3349 3350 3351 3352 3353 3354 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3349 class DeleteAgentRequest < Struct.new( :agent_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#skip_resource_in_use_check ⇒ Boolean
By default, this value is false and deletion is stopped if the
resource is in use. If you set it to true, the resource will be
deleted even if the resource is in use.
3349 3350 3351 3352 3353 3354 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3349 class DeleteAgentRequest < Struct.new( :agent_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |