Class: Aws::BedrockAgent::Types::DeleteFlowAliasRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#alias_identifierString

The unique identifier of the alias to be deleted.

Returns:

  • (String)


3470
3471
3472
3473
3474
3475
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3470

class DeleteFlowAliasRequest < Struct.new(
  :flow_identifier,
  :alias_identifier)
  SENSITIVE = []
  include Aws::Structure
end

#flow_identifierString

The unique identifier of the flow that the alias belongs to.

Returns:

  • (String)


3470
3471
3472
3473
3474
3475
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3470

class DeleteFlowAliasRequest < Struct.new(
  :flow_identifier,
  :alias_identifier)
  SENSITIVE = []
  include Aws::Structure
end