Class: Aws::BedrockAgent::Types::DeleteFlowVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_identifierString

The unique identifier of the flow whose version that you want to delete

Returns:



3542
3543
3544
3545
3546
3547
3548
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3542

class DeleteFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#flow_versionString

The version of the flow that you want to delete.

Returns:



3542
3543
3544
3545
3546
3547
3548
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3542

class DeleteFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_resource_in_use_checkBoolean

By default, this value is false and deletion is stopped if the resource is in use. If you set it to true, the resource will be deleted even if the resource is in use.

Returns:



3542
3543
3544
3545
3546
3547
3548
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3542

class DeleteFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end