Class: Aws::BedrockAgent::Types::DeletePromptResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DeletePromptResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#id ⇒ String
The unique identifier of the prompt that was deleted.
-
#version ⇒ String
The version of the prompt that was deleted.
Instance Attribute Details
#id ⇒ String
The unique identifier of the prompt that was deleted.
3678 3679 3680 3681 3682 3683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3678 class DeletePromptResponse < Struct.new( :id, :version) SENSITIVE = [] include Aws::Structure end |
#version ⇒ String
The version of the prompt that was deleted.
3678 3679 3680 3681 3682 3683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3678 class DeletePromptResponse < Struct.new( :id, :version) SENSITIVE = [] include Aws::Structure end |