Class: Aws::BedrockAgent::Types::DeletionProtectionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DeletionProtectionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Configuration for deletion protection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#deletion_protection_status ⇒ String
Enable or disable deletion protection for the connector.
-
#deletion_protection_threshold ⇒ Integer
The threshold is the maximum percentage of documents that a sync job can delete from your index.
Instance Attribute Details
#deletion_protection_status ⇒ String
Enable or disable deletion protection for the connector.
3738 3739 3740 3741 3742 3743 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3738 class DeletionProtectionConfiguration < Struct.new( :deletion_protection_status, :deletion_protection_threshold) SENSITIVE = [] include Aws::Structure end |
#deletion_protection_threshold ⇒ Integer
The threshold is the maximum percentage of documents that a sync job can delete from your index. If a sync would delete more than this percentage, the sync skips its delete phase, leaving your indexed documents in place. Not supported for the Custom connector.
3738 3739 3740 3741 3742 3743 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3738 class DeletionProtectionConfiguration < Struct.new( :deletion_protection_status, :deletion_protection_threshold) SENSITIVE = [] include Aws::Structure end |