Class: Aws::BedrockAgent::Types::DocumentContent
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DocumentContent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains information about the content of a document. Choose a ‘dataSourceType` and include the field that corresponds to it.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom ⇒ Types::CustomContent
Contains information about the content to ingest into a knowledge base connected to a custom data source.
-
#data_source_type ⇒ String
The type of data source that is connected to the knowledge base to which to ingest this document.
-
#s3 ⇒ Types::S3Content
Contains information about the content to ingest into a knowledge base connected to an Amazon S3 data source.
Instance Attribute Details
#custom ⇒ Types::CustomContent
Contains information about the content to ingest into a knowledge base connected to a custom data source.
3786 3787 3788 3789 3790 3791 3792 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3786 class DocumentContent < Struct.new( :data_source_type, :custom, :s3) SENSITIVE = [] include Aws::Structure end |
#data_source_type ⇒ String
The type of data source that is connected to the knowledge base to which to ingest this document.
3786 3787 3788 3789 3790 3791 3792 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3786 class DocumentContent < Struct.new( :data_source_type, :custom, :s3) SENSITIVE = [] include Aws::Structure end |
#s3 ⇒ Types::S3Content
Contains information about the content to ingest into a knowledge base connected to an Amazon S3 data source
3786 3787 3788 3789 3790 3791 3792 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3786 class DocumentContent < Struct.new( :data_source_type, :custom, :s3) SENSITIVE = [] include Aws::Structure end |