Class: Aws::BedrockAgent::Types::DuplicateConnectionsFlowValidationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Details about duplicate connections found between two nodes in the flow.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#sourceString

The name of the source node where the duplicate connection starts.

Returns:

  • (String)


3946
3947
3948
3949
3950
3951
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3946

class DuplicateConnectionsFlowValidationDetails < Struct.new(
  :source,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#targetString

The name of the target node where the duplicate connection ends.

Returns:

  • (String)


3946
3947
3948
3949
3950
3951
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3946

class DuplicateConnectionsFlowValidationDetails < Struct.new(
  :source,
  :target)
  SENSITIVE = []
  include Aws::Structure
end