Class: Aws::BedrockAgent::Types::FixedSizeChunkingConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::FixedSizeChunkingConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Configurations for when you choose fixed-size chunking. If you set the
chunkingStrategy as NONE, exclude this field.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_tokens ⇒ Integer
The maximum number of tokens to include in a chunk.
-
#overlap_percentage ⇒ Integer
The percentage of overlap between adjacent chunks of a data source.
Instance Attribute Details
#max_tokens ⇒ Integer
The maximum number of tokens to include in a chunk.
4010 4011 4012 4013 4014 4015 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4010 class FixedSizeChunkingConfiguration < Struct.new( :max_tokens, :overlap_percentage) SENSITIVE = [] include Aws::Structure end |
#overlap_percentage ⇒ Integer
The percentage of overlap between adjacent chunks of a data source.
4010 4011 4012 4013 4014 4015 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4010 class FixedSizeChunkingConfiguration < Struct.new( :max_tokens, :overlap_percentage) SENSITIVE = [] include Aws::Structure end |