Class: Aws::BedrockAgent::Types::FlowAliasSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains information about an alias of a flow.

This data type is used in the following API operations:

  • ListFlowAliases response][1

^

[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_ListFlowAliases.html#API_agent_ListFlowAliases_ResponseSyntax

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the alias.

Returns:

  • (String)


4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#concurrency_configurationTypes::FlowAliasConcurrencyConfiguration

The configuration that specifies how nodes in the flow are executed concurrently.



4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#created_atTime

The time at which the alias was created.

Returns:

  • (Time)


4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the alias.

Returns:

  • (String)


4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#flow_idString

The unique identifier of the flow.

Returns:

  • (String)


4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#idString

The unique identifier of the alias of the flow.

Returns:

  • (String)


4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the alias.

Returns:

  • (String)


4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#routing_configurationArray<Types::FlowAliasRoutingConfigurationListItem>

A list of configurations about the versions that the alias maps to. Currently, you can only specify one.



4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end

#updated_atTime

The time at which the alias was last updated.

Returns:

  • (Time)


4054
4055
4056
4057
4058
4059
4060
4061
4062
4063
4064
4065
4066
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4054

class FlowAliasSummary < Struct.new(
  :name,
  :description,
  :routing_configuration,
  :concurrency_configuration,
  :flow_id,
  :id,
  :arn,
  :created_at,
  :updated_at)
  SENSITIVE = []
  include Aws::Structure
end