Class: Aws::BedrockAgent::Types::FlowCondition

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Defines a condition in the condition node.

Constant Summary collapse

SENSITIVE =
[:expression]

Instance Attribute Summary collapse

Instance Attribute Details

#expressionString

Defines the condition. You must refer to at least one of the inputs in the condition. For more information, expand the Condition node section in Node types in prompt flows.

Returns:

  • (String)


4143
4144
4145
4146
4147
4148
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4143

class FlowCondition < Struct.new(
  :name,
  :expression)
  SENSITIVE = [:expression]
  include Aws::Structure
end

#nameString

A name for the condition that you can reference.

Returns:

  • (String)


4143
4144
4145
4146
4147
4148
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4143

class FlowCondition < Struct.new(
  :name,
  :expression)
  SENSITIVE = [:expression]
  include Aws::Structure
end