Class: Aws::BedrockAgent::Types::FlowConditionalConnectionConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::FlowConditionalConnectionConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
The configuration of a connection between a condition node and another node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#condition ⇒ String
The condition that triggers this connection.
Instance Attribute Details
#condition ⇒ String
The condition that triggers this connection. For more information about how to write conditions, see the Condition node type in the Node types topic in the Amazon Bedrock User Guide.
4108 4109 4110 4111 4112 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4108 class FlowConditionalConnectionConfiguration < Struct.new( :condition) SENSITIVE = [] include Aws::Structure end |