Class: Aws::BedrockAgent::Types::FlowNodeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Note:

FlowNodeConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

FlowNodeConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FlowNodeConfiguration corresponding to the set member.

Contains configurations for a node in your flow. For more information, see [Node types in a flow] in the Amazon Bedrock User Guide.

[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-nodes.html

Defined Under Namespace

Classes: Agent, Collector, Condition, InlineCode, Input, Iterator, KnowledgeBase, LambdaFunction, Lex, Loop, LoopController, LoopInput, Output, Prompt, Retrieval, Storage, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agentTypes::AgentFlowNodeConfiguration

Contains configurations for an agent node in your flow. Invokes an alias of an agent and returns the response.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#collectorTypes::CollectorFlowNodeConfiguration

Contains configurations for a collector node in your flow. Collects an iteration of inputs and consolidates them into an array of outputs.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#conditionTypes::ConditionFlowNodeConfiguration

Contains configurations for a condition node in your flow. Defines conditions that lead to different branches of the flow.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#inline_codeTypes::InlineCodeFlowNodeConfiguration

Contains configurations for an inline code node in your flow. Inline code nodes let you write and execute code directly within your flow, enabling data transformations, custom logic, and integrations without needing an external Lambda function.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#inputTypes::InputFlowNodeConfiguration

Contains configurations for an input flow node in your flow. The first node in the flow. ‘inputs` can’t be specified for this node.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#iteratorTypes::IteratorFlowNodeConfiguration

Contains configurations for an iterator node in your flow. Takes an input that is an array and iteratively sends each item of the array as an output to the following node. The size of the array is also returned in the output.

The output flow node at the end of the flow iteration will return a response for each member of the array. To return only one response, you can include a collector node downstream from the iterator node.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#knowledge_baseTypes::KnowledgeBaseFlowNodeConfiguration

Contains configurations for a knowledge base node in your flow. Queries a knowledge base and returns the retrieved results or generated response.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#lambda_functionTypes::LambdaFunctionFlowNodeConfiguration

Contains configurations for a Lambda function node in your flow. Invokes an Lambda function.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#lexTypes::LexFlowNodeConfiguration

Contains configurations for a Lex node in your flow. Invokes an Amazon Lex bot to identify the intent of the input and return the intent as the output.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#loopTypes::LoopFlowNodeConfiguration

Contains configurations for a DoWhile loop in your flow.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#loop_controllerTypes::LoopControllerFlowNodeConfiguration

Contains controller node configurations for a DoWhile loop in your flow.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#loop_inputTypes::LoopInputFlowNodeConfiguration

Contains input node configurations for a DoWhile loop in your flow.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#outputTypes::OutputFlowNodeConfiguration

Contains configurations for an output flow node in your flow. The last node in the flow. ‘outputs` can’t be specified for this node.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#promptTypes::PromptFlowNodeConfiguration

Contains configurations for a prompt node in your flow. Runs a prompt and generates the model response as the output. You can use a prompt from Prompt management or you can configure one in this node.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#retrievalTypes::RetrievalFlowNodeConfiguration

Contains configurations for a retrieval node in your flow. Retrieves data from an Amazon S3 location and returns it as the output.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#storageTypes::StorageFlowNodeConfiguration

Contains configurations for a storage node in your flow. Stores an input in an Amazon S3 location.



4361
4362
4363
4364
4365
4366
4367
4368
4369
4370
4371
4372
4373
4374
4375
4376
4377
4378
4379
4380
4381
4382
4383
4384
4385
4386
4387
4388
4389
4390
4391
4392
4393
4394
4395
4396
4397
4398
4399
4400
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

class FlowNodeConfiguration < Struct.new(
  :input,
  :output,
  :knowledge_base,
  :condition,
  :lex,
  :prompt,
  :lambda_function,
  :storage,
  :agent,
  :retrieval,
  :iterator,
  :collector,
  :inline_code,
  :loop,
  :loop_input,
  :loop_controller,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Input < FlowNodeConfiguration; end
  class Output < FlowNodeConfiguration; end
  class KnowledgeBase < FlowNodeConfiguration; end
  class Condition < FlowNodeConfiguration; end
  class Lex < FlowNodeConfiguration; end
  class Prompt < FlowNodeConfiguration; end
  class LambdaFunction < FlowNodeConfiguration; end
  class Storage < FlowNodeConfiguration; end
  class Agent < FlowNodeConfiguration; end
  class Retrieval < FlowNodeConfiguration; end
  class Iterator < FlowNodeConfiguration; end
  class Collector < FlowNodeConfiguration; end
  class InlineCode < FlowNodeConfiguration; end
  class Loop < FlowNodeConfiguration; end
  class LoopInput < FlowNodeConfiguration; end
  class LoopController < FlowNodeConfiguration; end
  class Unknown < FlowNodeConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4361
4362
4363
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4361

def unknown
  @unknown
end