Class: Aws::BedrockAgent::Types::FlowValidation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains information about validation of the flow.

This data type is used in the following API operations:

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#detailsTypes::FlowValidationDetails

Specific details about the validation issue encountered in the flow.



4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4572

class FlowValidation < Struct.new(
  :message,
  :severity,
  :details,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#messageString

A message describing the validation error.

Returns:

  • (String)


4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4572

class FlowValidation < Struct.new(
  :message,
  :severity,
  :details,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#severityString

The severity of the issue described in the message.

Returns:

  • (String)


4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4572

class FlowValidation < Struct.new(
  :message,
  :severity,
  :details,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of validation issue encountered in the flow.

Returns:

  • (String)


4572
4573
4574
4575
4576
4577
4578
4579
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4572

class FlowValidation < Struct.new(
  :message,
  :severity,
  :details,
  :type)
  SENSITIVE = []
  include Aws::Structure
end