Class: Aws::BedrockAgent::Types::Function

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Defines parameters that the agent needs to invoke from the user to complete the function. Corresponds to an action in an action group.

This data type is used in the following API operations:

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

A description of the function and its purpose.

Returns:

  • (String)


4946
4947
4948
4949
4950
4951
4952
4953
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4946

class Function < Struct.new(
  :name,
  :description,
  :parameters,
  :require_confirmation)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

A name for the function.

Returns:

  • (String)


4946
4947
4948
4949
4950
4951
4952
4953
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4946

class Function < Struct.new(
  :name,
  :description,
  :parameters,
  :require_confirmation)
  SENSITIVE = []
  include Aws::Structure
end

#parametersHash<String,Types::ParameterDetail>

The parameters that the agent elicits from the user to fulfill the function.

Returns:



4946
4947
4948
4949
4950
4951
4952
4953
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4946

class Function < Struct.new(
  :name,
  :description,
  :parameters,
  :require_confirmation)
  SENSITIVE = []
  include Aws::Structure
end

#require_confirmationString

Contains information if user confirmation is required to invoke the function.

Returns:

  • (String)


4946
4947
4948
4949
4950
4951
4952
4953
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4946

class Function < Struct.new(
  :name,
  :description,
  :parameters,
  :require_confirmation)
  SENSITIVE = []
  include Aws::Structure
end