Class: Aws::BedrockAgent::Types::FunctionSchema

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Note:

FunctionSchema is a union - when making an API calls you must set exactly one of the members.

Note:

FunctionSchema is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FunctionSchema corresponding to the set member.

Defines functions that each define parameters that the agent needs to invoke from the user. Each function represents an action in an action group.

This data type is used in the following API operations:

Defined Under Namespace

Classes: Functions, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#functionsArray<Types::Function>

A list of functions that each define an action in the action group.

Returns:



4989
4990
4991
4992
4993
4994
4995
4996
4997
4998
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4989

class FunctionSchema < Struct.new(
  :functions,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Functions < FunctionSchema; end
  class Unknown < FunctionSchema; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



4989
4990
4991
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4989

def unknown
  @unknown
end