Class: Aws::BedrockAgent::Types::GetFlowAliasRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::GetFlowAliasRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#alias_identifier ⇒ String
The unique identifier of the alias for which to retrieve information.
-
#flow_identifier ⇒ String
The unique identifier of the flow that the alias belongs to.
Instance Attribute Details
#alias_identifier ⇒ String
The unique identifier of the alias for which to retrieve information.
5229 5230 5231 5232 5233 5234 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5229 class GetFlowAliasRequest < Struct.new( :flow_identifier, :alias_identifier) SENSITIVE = [] include Aws::Structure end |
#flow_identifier ⇒ String
The unique identifier of the flow that the alias belongs to.
5229 5230 5231 5232 5233 5234 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5229 class GetFlowAliasRequest < Struct.new( :flow_identifier, :alias_identifier) SENSITIVE = [] include Aws::Structure end |