Class: Aws::BedrockAgent::Types::GetFlowResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:definition]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

The Amazon Resource Name (ARN) of the flow.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#created_atTime

The time at which the flow was created.

Returns:

  • (Time)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#customer_encryption_key_arnString

The Amazon Resource Name (ARN) of the KMS key that the flow is encrypted with.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#definitionTypes::FlowDefinition

The definition of the nodes and connections between the nodes in the flow.



5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#descriptionString

The description of the flow.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#execution_role_arnString

The Amazon Resource Name (ARN) of the service role with permissions to create a flow. For more information, see Create a service row for flows in the Amazon Bedrock User Guide.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#idString

The unique identifier of the flow.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#nameString

The name of the flow.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#statusString

The status of the flow. The following statuses are possible:

  • NotPrepared – The flow has been created or updated, but hasn't been prepared. If you just created the flow, you can't test it. If you updated the flow, the DRAFT version won't contain the latest changes for testing. Send a PrepareFlow request to package the latest changes into the DRAFT version.

  • Preparing – The flow is being prepared so that the DRAFT version contains the latest changes for testing.

  • Prepared – The flow is prepared and the DRAFT version contains the latest changes for testing.

  • Failed – The last API operation that you invoked on the flow failed. Send a GetFlow request and check the error message in the validations field.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#updated_atTime

The time at which the flow was last updated.

Returns:

  • (Time)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#validationsArray<Types::FlowValidation>

A list of validation error messages related to the last failed operation on the flow.

Returns:



5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end

#versionString

The version of the flow for which information was retrieved.

Returns:

  • (String)


5331
5332
5333
5334
5335
5336
5337
5338
5339
5340
5341
5342
5343
5344
5345
5346
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5331

class GetFlowResponse < Struct.new(
  :name,
  :description,
  :execution_role_arn,
  :customer_encryption_key_arn,
  :id,
  :arn,
  :status,
  :created_at,
  :updated_at,
  :version,
  :definition,
  :validations)
  SENSITIVE = [:definition]
  include Aws::Structure
end