Class: Aws::BedrockAgent::Types::GetFlowVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_identifierString

The unique identifier of the flow for which to get information.

Returns:

  • (String)


5364
5365
5366
5367
5368
5369
5370
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5364

class GetFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end

#flow_versionString

The version of the flow for which to get information.

Returns:

  • (String)


5364
5365
5366
5367
5368
5369
5370
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5364

class GetFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end

#included_dataString

Controls the scope of data returned. Set to ‘METADATA_ONLY` to return only resource metadata. Set to `ALL_DATA` or omit this field to return the full response.

Returns:

  • (String)


5364
5365
5366
5367
5368
5369
5370
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5364

class GetFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end