Class: Aws::BedrockAgent::Types::GetFlowVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::GetFlowVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:definition]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the flow.
-
#created_at ⇒ Time
The time at which the flow was created.
-
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key that the version of the flow is encrypted with.
-
#definition ⇒ Types::FlowDefinition
The definition of the nodes and connections between nodes in the flow.
-
#description ⇒ String
The description of the flow.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the service role with permissions to create a flow.
-
#id ⇒ String
The unique identifier of the flow.
-
#name ⇒ String
The name of the version.
-
#status ⇒ String
The status of the flow.
-
#version ⇒ String
The version of the flow for which information was retrieved.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the flow.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#created_at ⇒ Time
The time at which the flow was created.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key that the version of the flow is encrypted with.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#definition ⇒ Types::FlowDefinition
The definition of the nodes and connections between nodes in the flow.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#description ⇒ String
The description of the flow.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the service role with permissions to create a flow. For more information, see Create a service role for flows in Amazon Bedrock in the Amazon Bedrock User Guide.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#id ⇒ String
The unique identifier of the flow.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#name ⇒ String
The name of the version.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#status ⇒ String
The status of the flow.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#version ⇒ String
The version of the flow for which information was retrieved.
5479 5480 5481 5482 5483 5484 5485 5486 5487 5488 5489 5490 5491 5492 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5479 class GetFlowVersionResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |