Class: Aws::BedrockAgent::Types::GetKnowledgeBaseDocumentsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#data_source_idString

The unique identifier of the data source that contains the documents.

Returns:

  • (String)


5477
5478
5479
5480
5481
5482
5483
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5477

class GetKnowledgeBaseDocumentsRequest < Struct.new(
  :knowledge_base_id,
  :data_source_id,
  :document_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#document_identifiersArray<Types::DocumentIdentifier>

A list of objects, each of which contains information to identify a document for which to retrieve information.

Returns:



5477
5478
5479
5480
5481
5482
5483
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5477

class GetKnowledgeBaseDocumentsRequest < Struct.new(
  :knowledge_base_id,
  :data_source_id,
  :document_identifiers)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier of the knowledge base that is connected to the data source.

Returns:

  • (String)


5477
5478
5479
5480
5481
5482
5483
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5477

class GetKnowledgeBaseDocumentsRequest < Struct.new(
  :knowledge_base_id,
  :data_source_id,
  :document_identifiers)
  SENSITIVE = []
  include Aws::Structure
end