Class: Aws::BedrockAgent::Types::GetPromptRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::GetPromptRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#included_data ⇒ String
Controls the scope of data returned.
-
#prompt_identifier ⇒ String
The unique identifier of the prompt.
-
#prompt_version ⇒ String
The version of the prompt about which you want to retrieve information.
Instance Attribute Details
#included_data ⇒ String
Controls the scope of data returned. Set to METADATA_ONLY to
return only resource metadata. Set to ALL_DATA or omit this field
to return the full response.
5612 5613 5614 5615 5616 5617 5618 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5612 class GetPromptRequest < Struct.new( :prompt_identifier, :prompt_version, :included_data) SENSITIVE = [] include Aws::Structure end |
#prompt_identifier ⇒ String
The unique identifier of the prompt.
5612 5613 5614 5615 5616 5617 5618 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5612 class GetPromptRequest < Struct.new( :prompt_identifier, :prompt_version, :included_data) SENSITIVE = [] include Aws::Structure end |
#prompt_version ⇒ String
The version of the prompt about which you want to retrieve information. Omit this field to return information about the working draft of the prompt.
5612 5613 5614 5615 5616 5617 5618 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5612 class GetPromptRequest < Struct.new( :prompt_identifier, :prompt_version, :included_data) SENSITIVE = [] include Aws::Structure end |