Class: Aws::BedrockAgent::Types::GetPromptResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::GetPromptResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:variants]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the prompt or the prompt version (if you specified a version in the request).
-
#created_at ⇒ Time
The time at which the prompt was created.
-
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key that the prompt is encrypted with.
-
#default_variant ⇒ String
The name of the default variant for the prompt.
-
#description ⇒ String
The descriptino of the prompt.
-
#id ⇒ String
The unique identifier of the prompt.
-
#name ⇒ String
The name of the prompt.
-
#updated_at ⇒ Time
The time at which the prompt was last updated.
-
#variants ⇒ Array<Types::PromptVariant>
A list of objects, each containing details about a variant of the prompt.
-
#version ⇒ String
The version of the prompt.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the prompt or the prompt version (if you specified a version in the request).
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#created_at ⇒ Time
The time at which the prompt was created.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key that the prompt is encrypted with.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#default_variant ⇒ String
The name of the default variant for the prompt. This value must
match the name field in the relevant PromptVariant object.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#description ⇒ String
The descriptino of the prompt.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#id ⇒ String
The unique identifier of the prompt.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#name ⇒ String
The name of the prompt.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#updated_at ⇒ Time
The time at which the prompt was last updated.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#variants ⇒ Array<Types::PromptVariant>
A list of objects, each containing details about a variant of the prompt.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#version ⇒ String
The version of the prompt.
5670 5671 5672 5673 5674 5675 5676 5677 5678 5679 5680 5681 5682 5683 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5670 class GetPromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |