Class: Aws::BedrockAgent::Types::GetResourcePolicyResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::GetResourcePolicyResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#policy ⇒ String
The JSON-formatted resource policy associated with the knowledge base.
-
#resource_arn ⇒ String
The ARN of the knowledge base that the resource policy is associated with.
-
#revision_id ⇒ String
The revision identifier of the resource policy.
Instance Attribute Details
#policy ⇒ String
The JSON-formatted resource policy associated with the knowledge base.
5636 5637 5638 5639 5640 5641 5642 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5636 class GetResourcePolicyResponse < Struct.new( :resource_arn, :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The ARN of the knowledge base that the resource policy is associated with.
5636 5637 5638 5639 5640 5641 5642 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5636 class GetResourcePolicyResponse < Struct.new( :resource_arn, :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |
#revision_id ⇒ String
The revision identifier of the resource policy.
5636 5637 5638 5639 5640 5641 5642 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5636 class GetResourcePolicyResponse < Struct.new( :resource_arn, :policy, :revision_id) SENSITIVE = [] include Aws::Structure end |