Class: Aws::BedrockAgent::Types::IngestionJob
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::IngestionJob
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about a data ingestion job. Data sources are ingested into a knowledge base so that Large Language Models (LLMs) can use your data.
This data type is used in the following API operations:
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
The unique identifier of the data source for the data ingestion job.
-
#description ⇒ String
The description of the data ingestion job.
-
#failure_reasons ⇒ Array<String>
A list of reasons that the data ingestion job failed.
-
#ingestion_job_id ⇒ String
The unique identifier of the data ingestion job.
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge for the data ingestion job.
-
#started_at ⇒ Time
The time the data ingestion job started.
-
#statistics ⇒ Types::IngestionJobStatistics
Contains statistics about the data ingestion job.
-
#status ⇒ String
The status of the data ingestion job.
-
#updated_at ⇒ Time
The time the data ingestion job was last updated.
Instance Attribute Details
#data_source_id ⇒ String
The unique identifier of the data source for the data ingestion job.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
The description of the data ingestion job.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#failure_reasons ⇒ Array<String>
A list of reasons that the data ingestion job failed.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#ingestion_job_id ⇒ String
The unique identifier of the data ingestion job.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the knowledge for the data ingestion job.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#started_at ⇒ Time
The time the data ingestion job started.
If you stop a data ingestion job, the startedAt time is the time
the job was started before the job was stopped.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#statistics ⇒ Types::IngestionJobStatistics
Contains statistics about the data ingestion job.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#status ⇒ String
The status of the data ingestion job.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |
#updated_at ⇒ Time
The time the data ingestion job was last updated.
If you stop a data ingestion job, the updatedAt time is the time
the job was stopped.
5924 5925 5926 5927 5928 5929 5930 5931 5932 5933 5934 5935 5936 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5924 class IngestionJob < Struct.new( :knowledge_base_id, :data_source_id, :ingestion_job_id, :description, :status, :statistics, :failure_reasons, :started_at, :updated_at) SENSITIVE = [] include Aws::Structure end |