Class: Aws::BedrockAgent::Types::InlineCodeFlowNodeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains configurations for an inline code node in your flow. Inline code nodes let you write and execute code directly within your flow, enabling data transformations, custom logic, and integrations without needing an external Lambda function.

Constant Summary collapse

SENSITIVE =
[:code]

Instance Attribute Summary collapse

Instance Attribute Details

#codeString

The code that’s executed in your inline code node. The code can access input data from previous nodes in the flow, perform operations on that data, and produce output that can be used by other nodes in your flow.

The code must be valid in the programming ‘language` that you specify.

Returns:

  • (String)


6087
6088
6089
6090
6091
6092
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6087

class InlineCodeFlowNodeConfiguration < Struct.new(
  :code,
  :language)
  SENSITIVE = [:code]
  include Aws::Structure
end

#languageString

The programming language used by your inline code node.

The code must be valid in the programming ‘language` that you specify. Currently, only Python 3 (`Python_3`) is supported.

Returns:

  • (String)


6087
6088
6089
6090
6091
6092
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6087

class InlineCodeFlowNodeConfiguration < Struct.new(
  :code,
  :language)
  SENSITIVE = [:code]
  include Aws::Structure
end