Class: Aws::BedrockAgent::Types::InvalidLoopBoundaryFlowValidationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Details about a flow that contains connections that violate loop boundary rules.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connectionString

The name of the connection that violates loop boundary rules.

Returns:

  • (String)


6177
6178
6179
6180
6181
6182
6183
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6177

class InvalidLoopBoundaryFlowValidationDetails < Struct.new(
  :connection,
  :source,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#sourceString

The source node of the connection that violates DoWhile loop boundary rules.

Returns:

  • (String)


6177
6178
6179
6180
6181
6182
6183
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6177

class InvalidLoopBoundaryFlowValidationDetails < Struct.new(
  :connection,
  :source,
  :target)
  SENSITIVE = []
  include Aws::Structure
end

#targetString

The target node of the connection that violates DoWhile loop boundary rules.

Returns:

  • (String)


6177
6178
6179
6180
6181
6182
6183
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6177

class InvalidLoopBoundaryFlowValidationDetails < Struct.new(
  :connection,
  :source,
  :target)
  SENSITIVE = []
  include Aws::Structure
end