Class: Aws::BedrockAgent::Types::KnowledgeBaseConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::KnowledgeBaseConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about the vector embeddings configuration of the knowledge base.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kendra_knowledge_base_configuration ⇒ Types::KendraKnowledgeBaseConfiguration
Settings for an Amazon Kendra knowledge base.
-
#managed_knowledge_base_configuration ⇒ Types::ManagedKnowledgeBaseConfiguration
Contains configuration details for a knowledge base that uses a vector store fully managed by Amazon Bedrock.
-
#sql_knowledge_base_configuration ⇒ Types::SqlKnowledgeBaseConfiguration
Specifies configurations for a knowledge base connected to an SQL database.
-
#type ⇒ String
The type of data that the data source is converted into for the knowledge base.
-
#vector_knowledge_base_configuration ⇒ Types::VectorKnowledgeBaseConfiguration
Contains details about the model that's used to convert the data source into vector embeddings.
Instance Attribute Details
#kendra_knowledge_base_configuration ⇒ Types::KendraKnowledgeBaseConfiguration
Settings for an Amazon Kendra knowledge base.
6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6401 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |
#managed_knowledge_base_configuration ⇒ Types::ManagedKnowledgeBaseConfiguration
Contains configuration details for a knowledge base that uses a vector store fully managed by Amazon Bedrock. Specify this object when the knowledge base type is MANAGED.
6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6401 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |
#sql_knowledge_base_configuration ⇒ Types::SqlKnowledgeBaseConfiguration
Specifies configurations for a knowledge base connected to an SQL database.
6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6401 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of data that the data source is converted into for the
knowledge base. Choose MANAGED to create a managed knowledge base.
6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6401 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |
#vector_knowledge_base_configuration ⇒ Types::VectorKnowledgeBaseConfiguration
Contains details about the model that's used to convert the data source into vector embeddings.
6401 6402 6403 6404 6405 6406 6407 6408 6409 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6401 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |