Class: Aws::BedrockAgent::Types::ListDataSourcesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListDataSourcesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base for which to return a list of information.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, enter the token returned in thenextTokenfield in the response in this field to return the next batch of results.
Instance Attribute Details
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base for which to return a list of information.
7029 7030 7031 7032 7033 7034 7035 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7029 class ListDataSourcesRequest < Struct.new( :knowledge_base_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response. If the
total number of results is greater than this value, use the token
returned in the response in the nextToken field when making
another request to return the next batch of results.
7029 7030 7031 7032 7033 7034 7035 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7029 class ListDataSourcesRequest < Struct.new( :knowledge_base_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, enter the token returned in the
nextToken field in the response in this field to return the next
batch of results.
7029 7030 7031 7032 7033 7034 7035 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7029 class ListDataSourcesRequest < Struct.new( :knowledge_base_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |