Class: Aws::BedrockAgent::Types::ListFlowAliasesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListFlowAliasesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_identifier ⇒ String
The unique identifier of the flow for which aliases are being returned.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, enter the token returned in thenextTokenfield in the response in this field to return the next batch of results.
Instance Attribute Details
#flow_identifier ⇒ String
The unique identifier of the flow for which aliases are being returned.
7079 7080 7081 7082 7083 7084 7085 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7079 class ListFlowAliasesRequest < Struct.new( :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response. If the
total number of results is greater than this value, use the token
returned in the response in the nextToken field when making
another request to return the next batch of results.
7079 7080 7081 7082 7083 7084 7085 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7079 class ListFlowAliasesRequest < Struct.new( :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, enter the token returned in the
nextToken field in the response in this field to return the next
batch of results.
7079 7080 7081 7082 7083 7084 7085 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7079 class ListFlowAliasesRequest < Struct.new( :flow_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |