Class: Aws::BedrockAgent::Types::ListFlowAliasesResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_alias_summariesArray<Types::FlowAliasSummary>

A list, each member of which contains information about an alias.

Returns:



7100
7101
7102
7103
7104
7105
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7100

class ListFlowAliasesResponse < Struct.new(
  :flow_alias_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, use this token when making another request in the nextToken field to return the next batch of results.

Returns:

  • (String)


7100
7101
7102
7103
7104
7105
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7100

class ListFlowAliasesResponse < Struct.new(
  :flow_alias_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end