Class: Aws::BedrockAgent::Types::ListFlowVersionsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_identifierString

The unique identifier of the flow.

Returns:

  • (String)


7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7127

class ListFlowVersionsRequest < Struct.new(
  :flow_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

Returns:

  • (Integer)


7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7127

class ListFlowVersionsRequest < Struct.new(
  :flow_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.

Returns:

  • (String)


7127
7128
7129
7130
7131
7132
7133
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7127

class ListFlowVersionsRequest < Struct.new(
  :flow_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end