Class: Aws::BedrockAgent::Types::ListFlowsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_summariesArray<Types::FlowSummary>

A list, each member of which contains information about a flow.

Returns:



7191
7192
7193
7194
7195
7196
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7191

class ListFlowsResponse < Struct.new(
  :flow_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, use this token when making another request in the nextToken field to return the next batch of results.

Returns:

  • (String)


7191
7192
7193
7194
7195
7196
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7191

class ListFlowsResponse < Struct.new(
  :flow_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end