Class: Aws::BedrockAgent::Types::ListIngestionJobsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#ingestion_job_summariesArray<Types::IngestionJobSummary>

A list of data ingestion jobs with information about each job.

Returns:



7256
7257
7258
7259
7260
7261
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7256

class ListIngestionJobsResponse < Struct.new(
  :ingestion_job_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, use this token when making another request in the nextToken field to return the next batch of results.

Returns:

  • (String)


7256
7257
7258
7259
7260
7261
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7256

class ListIngestionJobsResponse < Struct.new(
  :ingestion_job_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end