Class: Aws::BedrockAgent::Types::ListKnowledgeBaseDocumentsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#document_detailsArray<Types::KnowledgeBaseDocumentDetail>

A list of objects, each of which contains information about the documents that were retrieved.



7312
7313
7314
7315
7316
7317
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7312

class ListKnowledgeBaseDocumentsResponse < Struct.new(
  :document_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, use this token when making another request in the nextToken field to return the next batch of results.

Returns:

  • (String)


7312
7313
7314
7315
7316
7317
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7312

class ListKnowledgeBaseDocumentsResponse < Struct.new(
  :document_details,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end