Class: Aws::BedrockAgent::Types::ListPromptsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_resultsInteger

The maximum number of results to return in the response. If the total number of results is greater than this value, use the token returned in the response in the nextToken field when making another request to return the next batch of results.

Returns:

  • (Integer)


7385
7386
7387
7388
7389
7390
7391
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7385

class ListPromptsRequest < Struct.new(
  :prompt_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, enter the token returned in the nextToken field in the response in this field to return the next batch of results.

Returns:

  • (String)


7385
7386
7387
7388
7389
7390
7391
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7385

class ListPromptsRequest < Struct.new(
  :prompt_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_identifierString

The unique identifier of the prompt for whose versions you want to return information. Omit this field to list information about all prompts in an account.

Returns:

  • (String)


7385
7386
7387
7388
7389
7390
7391
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7385

class ListPromptsRequest < Struct.new(
  :prompt_identifier,
  :max_results,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end