Class: Aws::BedrockAgent::Types::ListPromptsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#next_tokenString

If the total number of results is greater than the maxResults value provided in the request, use this token when making another request in the nextToken field to return the next batch of results.

Returns:

  • (String)


7407
7408
7409
7410
7411
7412
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7407

class ListPromptsResponse < Struct.new(
  :prompt_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_summariesArray<Types::PromptSummary>

A list, each member of which contains information about a prompt using Prompt management.

Returns:



7407
7408
7409
7410
7411
7412
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7407

class ListPromptsResponse < Struct.new(
  :prompt_summaries,
  :next_token)
  SENSITIVE = []
  include Aws::Structure
end