Class: Aws::BedrockAgent::Types::MalformedConditionExpressionFlowValidationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::MalformedConditionExpressionFlowValidationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Details about a malformed condition expression in a node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cause ⇒ String
The error message describing why the condition expression is malformed.
-
#condition ⇒ String
The name of the malformed condition.
-
#node ⇒ String
The name of the node containing the malformed condition expression.
Instance Attribute Details
#cause ⇒ String
The error message describing why the condition expression is malformed.
7556 7557 7558 7559 7560 7561 7562 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7556 class MalformedConditionExpressionFlowValidationDetails < Struct.new( :node, :condition, :cause) SENSITIVE = [] include Aws::Structure end |
#condition ⇒ String
The name of the malformed condition.
7556 7557 7558 7559 7560 7561 7562 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7556 class MalformedConditionExpressionFlowValidationDetails < Struct.new( :node, :condition, :cause) SENSITIVE = [] include Aws::Structure end |
#node ⇒ String
The name of the node containing the malformed condition expression.
7556 7557 7558 7559 7560 7561 7562 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7556 class MalformedConditionExpressionFlowValidationDetails < Struct.new( :node, :condition, :cause) SENSITIVE = [] include Aws::Structure end |