Class: Aws::BedrockAgent::Types::MalformedNodeInputExpressionFlowValidationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::MalformedNodeInputExpressionFlowValidationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Details about a malformed input expression in a node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cause ⇒ String
The error message describing why the input expression is malformed.
-
#input ⇒ String
The name of the input with the malformed expression.
-
#node ⇒ String
The name of the node containing the malformed input expression.
Instance Attribute Details
#cause ⇒ String
The error message describing why the input expression is malformed.
7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7491 class MalformedNodeInputExpressionFlowValidationDetails < Struct.new( :node, :input, :cause) SENSITIVE = [] include Aws::Structure end |
#input ⇒ String
The name of the input with the malformed expression.
7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7491 class MalformedNodeInputExpressionFlowValidationDetails < Struct.new( :node, :input, :cause) SENSITIVE = [] include Aws::Structure end |
#node ⇒ String
The name of the node containing the malformed input expression.
7491 7492 7493 7494 7495 7496 7497 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7491 class MalformedNodeInputExpressionFlowValidationDetails < Struct.new( :node, :input, :cause) SENSITIVE = [] include Aws::Structure end |