Class: Aws::BedrockAgent::Types::ManagedKnowledgeBaseConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Configurations for a managed knowledge base.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#embedding_model_arnString

The ARN for the embeddings model.

Returns:

  • (String)


7617
7618
7619
7620
7621
7622
7623
7624
7625
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7617

class ManagedKnowledgeBaseConfiguration < Struct.new(
  :embedding_model_type,
  :embedding_model_arn,
  :embedding_model_configuration,
  :server_side_encryption_configuration,
  :supplemental_data_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#embedding_model_configurationTypes::EmbeddingModelConfiguration

The configuration details for the embeddings model. Not required when choosing the MANAGED embeddingModelType.



7617
7618
7619
7620
7621
7622
7623
7624
7625
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7617

class ManagedKnowledgeBaseConfiguration < Struct.new(
  :embedding_model_type,
  :embedding_model_arn,
  :embedding_model_configuration,
  :server_side_encryption_configuration,
  :supplemental_data_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#embedding_model_typeString

Choose CUSTOM to provide your own Bedrock embedding model ARN. Choose MANAGED to use a service-managed embedding model.

Returns:

  • (String)


7617
7618
7619
7620
7621
7622
7623
7624
7625
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7617

class ManagedKnowledgeBaseConfiguration < Struct.new(
  :embedding_model_type,
  :embedding_model_arn,
  :embedding_model_configuration,
  :server_side_encryption_configuration,
  :supplemental_data_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#server_side_encryption_configurationTypes::ServerSideEncryptionConfiguration

Contains the configuration for server-side encryption for your managed knowledge base.



7617
7618
7619
7620
7621
7622
7623
7624
7625
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7617

class ManagedKnowledgeBaseConfiguration < Struct.new(
  :embedding_model_type,
  :embedding_model_arn,
  :embedding_model_configuration,
  :server_side_encryption_configuration,
  :supplemental_data_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#supplemental_data_storage_configurationTypes::SupplementalDataStorageConfiguration

Use this object to specify the Amazon S3 location that the knowledge base uses to process and ingest multimodal content. This field is required when you use a native multimodal embedding model.



7617
7618
7619
7620
7621
7622
7623
7624
7625
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7617

class ManagedKnowledgeBaseConfiguration < Struct.new(
  :embedding_model_type,
  :embedding_model_arn,
  :embedding_model_configuration,
  :server_side_encryption_configuration,
  :supplemental_data_storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end