Class: Aws::BedrockAgent::Types::ManagedKnowledgeBaseConnectorConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Configuration for managed knowledge base connector data sources.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connector_parametersHash, ...

Connector-specific parameters. For more information, see Connect a data source.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7656

class ManagedKnowledgeBaseConnectorConfiguration < Struct.new(
  :deletion_protection_configuration,
  :media_extraction_configuration,
  :connector_parameters,
  :sync_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_configurationTypes::DeletionProtectionConfiguration

A safeguard against accidental bulk deletion of indexed content.



7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7656

class ManagedKnowledgeBaseConnectorConfiguration < Struct.new(
  :deletion_protection_configuration,
  :media_extraction_configuration,
  :connector_parameters,
  :sync_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#media_extraction_configurationTypes::MediaExtractionConfiguration

Configuration for extracting media (images, audio, video) from data source files.



7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7656

class ManagedKnowledgeBaseConnectorConfiguration < Struct.new(
  :deletion_protection_configuration,
  :media_extraction_configuration,
  :connector_parameters,
  :sync_schedule)
  SENSITIVE = []
  include Aws::Structure
end

#sync_scheduleTypes::SyncSchedule

The recurring schedule on which the connector automatically syncs this data source. If not specified, the data source is not synced automatically and you start each sync yourself. Not supported for the Custom connector.

Returns:



7656
7657
7658
7659
7660
7661
7662
7663
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7656

class ManagedKnowledgeBaseConnectorConfiguration < Struct.new(
  :deletion_protection_configuration,
  :media_extraction_configuration,
  :connector_parameters,
  :sync_schedule)
  SENSITIVE = []
  include Aws::Structure
end