Class: Aws::BedrockAgent::Types::MetadataConfigurationForReranking

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Specifies how metadata fields should be handled during the reranking process.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#selection_modeString

The mode for selecting metadata fields for reranking.

Returns:

  • (String)


7807
7808
7809
7810
7811
7812
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7807

class MetadataConfigurationForReranking < Struct.new(
  :selection_mode,
  :selective_mode_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#selective_mode_configurationTypes::RerankingMetadataSelectiveModeConfiguration

The configuration for selective metadata field inclusion or exclusion during reranking.



7807
7808
7809
7810
7811
7812
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7807

class MetadataConfigurationForReranking < Struct.new(
  :selection_mode,
  :selective_mode_configuration)
  SENSITIVE = []
  include Aws::Structure
end