Class: Aws::BedrockAgent::Types::MissingNodeInputFlowValidationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Details about a missing required input in a node.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inputString

The name of the missing input.

Returns:

  • (String)


7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7878

class MissingNodeInputFlowValidationDetails < Struct.new(
  :node,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#nodeString

The name of the node missing the required input.

Returns:

  • (String)


7878
7879
7880
7881
7882
7883
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7878

class MissingNodeInputFlowValidationDetails < Struct.new(
  :node,
  :input)
  SENSITIVE = []
  include Aws::Structure
end