Class: Aws::BedrockAgent::Types::MissingNodeOutputFlowValidationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::MissingNodeOutputFlowValidationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Details about a missing required output in a node.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#node ⇒ String
The name of the node missing the required output.
-
#output ⇒ String
The name of the missing output.
Instance Attribute Details
#node ⇒ String
The name of the node missing the required output.
7876 7877 7878 7879 7880 7881 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7876 class MissingNodeOutputFlowValidationDetails < Struct.new( :node, :output) SENSITIVE = [] include Aws::Structure end |
#output ⇒ String
The name of the missing output.
7876 7877 7878 7879 7880 7881 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7876 class MissingNodeOutputFlowValidationDetails < Struct.new( :node, :output) SENSITIVE = [] include Aws::Structure end |