Class: Aws::BedrockAgent::Types::MongoDbAtlasConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::MongoDbAtlasConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about the storage configuration of the knowledge base in MongoDB Atlas.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#collection_name ⇒ String
The collection name of the knowledge base in MongoDB Atlas.
-
#credentials_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret that you created in Secrets Manager that contains user credentials for your MongoDB Atlas cluster.
-
#database_name ⇒ String
The database name in your MongoDB Atlas cluster for your knowledge base.
-
#endpoint ⇒ String
The endpoint URL of your MongoDB Atlas cluster for your knowledge base.
-
#endpoint_service_name ⇒ String
The name of the VPC endpoint service in your account that is connected to your MongoDB Atlas cluster.
-
#field_mapping ⇒ Types::MongoDbAtlasFieldMapping
Contains the names of the fields to which to map information about the vector store.
-
#text_index_name ⇒ String
The name of the text search index in the MongoDB collection.
-
#vector_index_name ⇒ String
The name of the MongoDB Atlas vector search index.
Instance Attribute Details
#collection_name ⇒ String
The collection name of the knowledge base in MongoDB Atlas.
8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8034 class MongoDbAtlasConfiguration < Struct.new( :endpoint, :database_name, :collection_name, :vector_index_name, :credentials_secret_arn, :field_mapping, :endpoint_service_name, :text_index_name) SENSITIVE = [] include Aws::Structure end |
#credentials_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret that you created in Secrets Manager that contains user credentials for your MongoDB Atlas cluster.
8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8034 class MongoDbAtlasConfiguration < Struct.new( :endpoint, :database_name, :collection_name, :vector_index_name, :credentials_secret_arn, :field_mapping, :endpoint_service_name, :text_index_name) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The database name in your MongoDB Atlas cluster for your knowledge base.
8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8034 class MongoDbAtlasConfiguration < Struct.new( :endpoint, :database_name, :collection_name, :vector_index_name, :credentials_secret_arn, :field_mapping, :endpoint_service_name, :text_index_name) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint URL of your MongoDB Atlas cluster for your knowledge base.
8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8034 class MongoDbAtlasConfiguration < Struct.new( :endpoint, :database_name, :collection_name, :vector_index_name, :credentials_secret_arn, :field_mapping, :endpoint_service_name, :text_index_name) SENSITIVE = [] include Aws::Structure end |
#endpoint_service_name ⇒ String
The name of the VPC endpoint service in your account that is connected to your MongoDB Atlas cluster.
8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8034 class MongoDbAtlasConfiguration < Struct.new( :endpoint, :database_name, :collection_name, :vector_index_name, :credentials_secret_arn, :field_mapping, :endpoint_service_name, :text_index_name) SENSITIVE = [] include Aws::Structure end |
#field_mapping ⇒ Types::MongoDbAtlasFieldMapping
Contains the names of the fields to which to map information about the vector store.
8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8034 class MongoDbAtlasConfiguration < Struct.new( :endpoint, :database_name, :collection_name, :vector_index_name, :credentials_secret_arn, :field_mapping, :endpoint_service_name, :text_index_name) SENSITIVE = [] include Aws::Structure end |
#text_index_name ⇒ String
The name of the text search index in the MongoDB collection. This is required for using the hybrid search feature.
8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8034 class MongoDbAtlasConfiguration < Struct.new( :endpoint, :database_name, :collection_name, :vector_index_name, :credentials_secret_arn, :field_mapping, :endpoint_service_name, :text_index_name) SENSITIVE = [] include Aws::Structure end |
#vector_index_name ⇒ String
The name of the MongoDB Atlas vector search index.
8034 8035 8036 8037 8038 8039 8040 8041 8042 8043 8044 8045 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8034 class MongoDbAtlasConfiguration < Struct.new( :endpoint, :database_name, :collection_name, :vector_index_name, :credentials_secret_arn, :field_mapping, :endpoint_service_name, :text_index_name) SENSITIVE = [] include Aws::Structure end |