Class: Aws::BedrockAgent::Types::MongoDbAtlasFieldMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::MongoDbAtlasFieldMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains the names of the fields to which to map information about the vector store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata_field ⇒ String
The name of the field in which Amazon Bedrock stores metadata about the vector store.
-
#text_field ⇒ String
The name of the field in which Amazon Bedrock stores the raw text from your data.
-
#vector_field ⇒ String
The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
Instance Attribute Details
#metadata_field ⇒ String
The name of the field in which Amazon Bedrock stores metadata about the vector store.
8068 8069 8070 8071 8072 8073 8074 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8068 class MongoDbAtlasFieldMapping < Struct.new( :vector_field, :text_field, :metadata_field) SENSITIVE = [] include Aws::Structure end |
#text_field ⇒ String
The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
8068 8069 8070 8071 8072 8073 8074 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8068 class MongoDbAtlasFieldMapping < Struct.new( :vector_field, :text_field, :metadata_field) SENSITIVE = [] include Aws::Structure end |
#vector_field ⇒ String
The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
8068 8069 8070 8071 8072 8073 8074 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8068 class MongoDbAtlasFieldMapping < Struct.new( :vector_field, :text_field, :metadata_field) SENSITIVE = [] include Aws::Structure end |