Class: Aws::BedrockAgent::Types::MonthlySchedule
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::MonthlySchedule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
A monthly sync on a specified day of the month.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#day_of_month ⇒ Types::DayOfMonth
The day of the month on which the monthly sync runs.
Instance Attribute Details
#day_of_month ⇒ Types::DayOfMonth
The day of the month on which the monthly sync runs.
8084 8085 8086 8087 8088 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8084 class MonthlySchedule < Struct.new( :day_of_month) SENSITIVE = [] include Aws::Structure end |