Class: Aws::BedrockAgent::Types::NeptuneAnalyticsFieldMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::NeptuneAnalyticsFieldMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains the names of the fields to which to map information about the vector store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata_field ⇒ String
The name of the field in which Amazon Bedrock stores metadata about the vector store.
-
#text_field ⇒ String
The name of the field in which Amazon Bedrock stores the raw text from your data.
Instance Attribute Details
#metadata_field ⇒ String
The name of the field in which Amazon Bedrock stores metadata about the vector store.
8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8183 class NeptuneAnalyticsFieldMapping < Struct.new( :text_field, :metadata_field) SENSITIVE = [] include Aws::Structure end |
#text_field ⇒ String
The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
8183 8184 8185 8186 8187 8188 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8183 class NeptuneAnalyticsFieldMapping < Struct.new( :text_field, :metadata_field) SENSITIVE = [] include Aws::Structure end |