Class: Aws::BedrockAgent::Types::OutputFlowNodeConfiguration Private
- Inherits:
-
EmptyStructure
- Object
- EmptyStructure
- Aws::BedrockAgent::Types::OutputFlowNodeConfiguration
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
This class is part of a private API. You should avoid using this class if possible, as it may be removed or be changed in the future.
Contains configurations for an output flow node in the flow. You
specify the data type expected for the input into the node in the
type field and how to return the final output in the expression
field.