Class: Aws::BedrockAgent::Types::ParameterDetail
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ParameterDetail
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about a parameter in a function for an action group.
This data type is used in the following API operations:
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the parameter.
-
#required ⇒ Boolean
Whether the parameter is required for the agent to complete the function for action group invocation.
-
#type ⇒ String
The data type of the parameter.
Instance Attribute Details
#description ⇒ String
A description of the parameter. Helps the foundation model determine how to elicit the parameters from the user.
8391 8392 8393 8394 8395 8396 8397 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8391 class ParameterDetail < Struct.new( :description, :type, :required) SENSITIVE = [] include Aws::Structure end |
#required ⇒ Boolean
Whether the parameter is required for the agent to complete the function for action group invocation.
8391 8392 8393 8394 8395 8396 8397 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8391 class ParameterDetail < Struct.new( :description, :type, :required) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The data type of the parameter.
8391 8392 8393 8394 8395 8396 8397 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8391 class ParameterDetail < Struct.new( :description, :type, :required) SENSITIVE = [] include Aws::Structure end |