Class: Aws::BedrockAgent::Types::PrepareAgentRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::PrepareAgentRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier of the agent for which to create a
DRAFTversion.
Instance Attribute Details
#agent_id ⇒ String
The unique identifier of the agent for which to create a DRAFT
version.
8605 8606 8607 8608 8609 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8605 class PrepareAgentRequest < Struct.new( :agent_id) SENSITIVE = [] include Aws::Structure end |