Class: Aws::BedrockAgent::Types::PromptFlowNodeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains configurations for a prompt node in the flow. You can use a prompt from Prompt management or you can define one in this node. If the prompt contains variables, the inputs into this node will fill in the variables. The output from this node is the response generated by the model. For more information, see [Node types in a flow] in the Amazon Bedrock User Guide.

[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-nodes.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#guardrail_configurationTypes::GuardrailConfiguration

Contains configurations for a guardrail to apply to the prompt in this node and the response generated from it.



8711
8712
8713
8714
8715
8716
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8711

class PromptFlowNodeConfiguration < Struct.new(
  :source_configuration,
  :guardrail_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#source_configurationTypes::PromptFlowNodeSourceConfiguration

Specifies whether the prompt is from Prompt management or defined inline.



8711
8712
8713
8714
8715
8716
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8711

class PromptFlowNodeConfiguration < Struct.new(
  :source_configuration,
  :guardrail_configuration)
  SENSITIVE = []
  include Aws::Structure
end