Class: Aws::BedrockAgent::Types::PromptFlowNodeInlineConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains configurations for a prompt defined inline in the node.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#additional_model_request_fieldsHash, ...

Additional fields to be included in the model request for the Prompt node.

Returns:

  • (Hash, Array, String, Numeric, Boolean)


8749
8750
8751
8752
8753
8754
8755
8756
8757
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8749

class PromptFlowNodeInlineConfiguration < Struct.new(
  :template_type,
  :template_configuration,
  :model_id,
  :inference_configuration,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end

#inference_configurationTypes::PromptInferenceConfiguration

Contains inference configurations for the prompt.



8749
8750
8751
8752
8753
8754
8755
8756
8757
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8749

class PromptFlowNodeInlineConfiguration < Struct.new(
  :template_type,
  :template_configuration,
  :model_id,
  :inference_configuration,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end

#model_idString

The unique identifier of the model or [inference profile] to run inference with.

[1]: docs.aws.amazon.com/bedrock/latest/userguide/cross-region-inference.html

Returns:

  • (String)


8749
8750
8751
8752
8753
8754
8755
8756
8757
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8749

class PromptFlowNodeInlineConfiguration < Struct.new(
  :template_type,
  :template_configuration,
  :model_id,
  :inference_configuration,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end

#template_configurationTypes::PromptTemplateConfiguration

Contains a prompt and variables in the prompt that can be replaced with values at runtime.



8749
8750
8751
8752
8753
8754
8755
8756
8757
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8749

class PromptFlowNodeInlineConfiguration < Struct.new(
  :template_type,
  :template_configuration,
  :model_id,
  :inference_configuration,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end

#template_typeString

The type of prompt template.

Returns:

  • (String)


8749
8750
8751
8752
8753
8754
8755
8756
8757
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8749

class PromptFlowNodeInlineConfiguration < Struct.new(
  :template_type,
  :template_configuration,
  :model_id,
  :inference_configuration,
  :additional_model_request_fields)
  SENSITIVE = []
  include Aws::Structure
end