Class: Aws::BedrockAgent::Types::PromptGenAiResource
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::PromptGenAiResource
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Note:
PromptGenAiResource is a union - when making an API calls you must set exactly one of the members.
Note:
PromptGenAiResource is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of PromptGenAiResource corresponding to the set member.
Contains specifications for a generative AI resource with which to use the prompt. For more information, see [Create a prompt using Prompt management].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-management-create.html
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[:agent]
Instance Attribute Summary collapse
-
#agent ⇒ Types::PromptAgentResource
Specifies an Amazon Bedrock agent with which to use the prompt.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#agent ⇒ Types::PromptAgentResource
Specifies an Amazon Bedrock agent with which to use the prompt.
8801 8802 8803 8804 8805 8806 8807 8808 8809 8810 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8801 class PromptGenAiResource < Struct.new( :agent, :unknown) SENSITIVE = [:agent] include Aws::Structure include Aws::Structure::Union class Agent < PromptGenAiResource; end class Unknown < PromptGenAiResource; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8801 8802 8803 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8801 def unknown @unknown end |