Class: Aws::BedrockAgent::Types::PutResourcePolicyRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#expected_revision_idString

The expected revision identifier of the resource policy. Use this to prevent conflicts when multiple users update the same policy concurrently. Specify the revisionId from the most recent GetResourcePolicy or PutResourcePolicy response.

Returns:

  • (String)


9248
9249
9250
9251
9252
9253
9254
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9248

class PutResourcePolicyRequest < Struct.new(
  :resource_arn,
  :policy,
  :expected_revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#policyString

The JSON-formatted resource policy to associate with the knowledge base.

Returns:

  • (String)


9248
9249
9250
9251
9252
9253
9254
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9248

class PutResourcePolicyRequest < Struct.new(
  :resource_arn,
  :policy,
  :expected_revision_id)
  SENSITIVE = []
  include Aws::Structure
end

#resource_arnString

The Amazon Resource Name (ARN) of the knowledge base to attach the resource policy to.

Returns:

  • (String)


9248
9249
9250
9251
9252
9253
9254
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9248

class PutResourcePolicyRequest < Struct.new(
  :resource_arn,
  :policy,
  :expected_revision_id)
  SENSITIVE = []
  include Aws::Structure
end