Class: Aws::BedrockAgent::Types::QueryGenerationTable

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains information about a table for the query engine to consider.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#columnsArray<Types::QueryGenerationColumn>

An array of objects, each of which defines information about a column in the table.

Returns:



9378
9379
9380
9381
9382
9383
9384
9385
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9378

class QueryGenerationTable < Struct.new(
  :name,
  :description,
  :inclusion,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the table that helps the query engine understand the contents of the table.

Returns:

  • (String)


9378
9379
9380
9381
9382
9383
9384
9385
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9378

class QueryGenerationTable < Struct.new(
  :name,
  :description,
  :inclusion,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#inclusionString

Specifies whether to include or exclude the table during query generation. If you specify EXCLUDE, the table will be ignored. If you specify INCLUDE, all other tables will be ignored.

Returns:

  • (String)


9378
9379
9380
9381
9382
9383
9384
9385
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9378

class QueryGenerationTable < Struct.new(
  :name,
  :description,
  :inclusion,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

The name of the table for which the other fields in this object apply.

Returns:

  • (String)


9378
9379
9380
9381
9382
9383
9384
9385
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9378

class QueryGenerationTable < Struct.new(
  :name,
  :description,
  :inclusion,
  :columns)
  SENSITIVE = []
  include Aws::Structure
end