Class: Aws::BedrockAgent::Types::RdsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::RdsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about the storage configuration of the knowledge base in Amazon RDS. For more information, see Create a vector index in Amazon RDS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credentials_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret that you created in Secrets Manager that is linked to your Amazon RDS database.
-
#database_name ⇒ String
The name of your Amazon RDS database.
-
#field_mapping ⇒ Types::RdsFieldMapping
Contains the names of the fields to which to map information about the vector store.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the vector store.
-
#table_name ⇒ String
The name of the table in the database.
Instance Attribute Details
#credentials_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret that you created in Secrets Manager that is linked to your Amazon RDS database.
9419 9420 9421 9422 9423 9424 9425 9426 9427 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9419 class RdsConfiguration < Struct.new( :resource_arn, :credentials_secret_arn, :database_name, :table_name, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#database_name ⇒ String
The name of your Amazon RDS database.
9419 9420 9421 9422 9423 9424 9425 9426 9427 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9419 class RdsConfiguration < Struct.new( :resource_arn, :credentials_secret_arn, :database_name, :table_name, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#field_mapping ⇒ Types::RdsFieldMapping
Contains the names of the fields to which to map information about the vector store.
9419 9420 9421 9422 9423 9424 9425 9426 9427 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9419 class RdsConfiguration < Struct.new( :resource_arn, :credentials_secret_arn, :database_name, :table_name, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the vector store.
9419 9420 9421 9422 9423 9424 9425 9426 9427 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9419 class RdsConfiguration < Struct.new( :resource_arn, :credentials_secret_arn, :database_name, :table_name, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#table_name ⇒ String
The name of the table in the database.
9419 9420 9421 9422 9423 9424 9425 9426 9427 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9419 class RdsConfiguration < Struct.new( :resource_arn, :credentials_secret_arn, :database_name, :table_name, :field_mapping) SENSITIVE = [] include Aws::Structure end |