Class: Aws::BedrockAgent::Types::RdsFieldMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::RdsFieldMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains the names of the fields to which to map information about the vector store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#custom_metadata_field ⇒ String
Provide a name for the universal metadata field where Amazon Bedrock will store any custom metadata from your data source.
-
#metadata_field ⇒ String
The name of the field in which Amazon Bedrock stores metadata about the vector store.
-
#primary_key_field ⇒ String
The name of the field in which Amazon Bedrock stores the ID for each entry.
-
#text_field ⇒ String
The name of the field in which Amazon Bedrock stores the raw text from your data.
-
#vector_field ⇒ String
The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
Instance Attribute Details
#custom_metadata_field ⇒ String
Provide a name for the universal metadata field where Amazon Bedrock will store any custom metadata from your data source.
9460 9461 9462 9463 9464 9465 9466 9467 9468 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9460 class RdsFieldMapping < Struct.new( :primary_key_field, :vector_field, :text_field, :metadata_field, :custom_metadata_field) SENSITIVE = [] include Aws::Structure end |
#metadata_field ⇒ String
The name of the field in which Amazon Bedrock stores metadata about the vector store.
9460 9461 9462 9463 9464 9465 9466 9467 9468 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9460 class RdsFieldMapping < Struct.new( :primary_key_field, :vector_field, :text_field, :metadata_field, :custom_metadata_field) SENSITIVE = [] include Aws::Structure end |
#primary_key_field ⇒ String
The name of the field in which Amazon Bedrock stores the ID for each entry.
9460 9461 9462 9463 9464 9465 9466 9467 9468 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9460 class RdsFieldMapping < Struct.new( :primary_key_field, :vector_field, :text_field, :metadata_field, :custom_metadata_field) SENSITIVE = [] include Aws::Structure end |
#text_field ⇒ String
The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
9460 9461 9462 9463 9464 9465 9466 9467 9468 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9460 class RdsFieldMapping < Struct.new( :primary_key_field, :vector_field, :text_field, :metadata_field, :custom_metadata_field) SENSITIVE = [] include Aws::Structure end |
#vector_field ⇒ String
The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
9460 9461 9462 9463 9464 9465 9466 9467 9468 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9460 class RdsFieldMapping < Struct.new( :primary_key_field, :vector_field, :text_field, :metadata_field, :custom_metadata_field) SENSITIVE = [] include Aws::Structure end |