Class: Aws::BedrockAgent::Types::RedisEnterpriseCloudConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::RedisEnterpriseCloudConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about the storage configuration of the knowledge base in Redis Enterprise Cloud. For more information, see [Create a vector index in Redis Enterprise Cloud].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-setup-oss.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#credentials_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret that you created in Secrets Manager that is linked to your Redis Enterprise Cloud database.
-
#endpoint ⇒ String
The endpoint URL of the Redis Enterprise Cloud database.
-
#field_mapping ⇒ Types::RedisEnterpriseCloudFieldMapping
Contains the names of the fields to which to map information about the vector store.
-
#vector_index_name ⇒ String
The name of the vector index.
Instance Attribute Details
#credentials_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret that you created in Secrets Manager that is linked to your Redis Enterprise Cloud database.
9394 9395 9396 9397 9398 9399 9400 9401 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9394 class RedisEnterpriseCloudConfiguration < Struct.new( :endpoint, :vector_index_name, :credentials_secret_arn, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#endpoint ⇒ String
The endpoint URL of the Redis Enterprise Cloud database.
9394 9395 9396 9397 9398 9399 9400 9401 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9394 class RedisEnterpriseCloudConfiguration < Struct.new( :endpoint, :vector_index_name, :credentials_secret_arn, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#field_mapping ⇒ Types::RedisEnterpriseCloudFieldMapping
Contains the names of the fields to which to map information about the vector store.
9394 9395 9396 9397 9398 9399 9400 9401 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9394 class RedisEnterpriseCloudConfiguration < Struct.new( :endpoint, :vector_index_name, :credentials_secret_arn, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#vector_index_name ⇒ String
The name of the vector index.
9394 9395 9396 9397 9398 9399 9400 9401 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9394 class RedisEnterpriseCloudConfiguration < Struct.new( :endpoint, :vector_index_name, :credentials_secret_arn, :field_mapping) SENSITIVE = [] include Aws::Structure end |