Class: Aws::BedrockAgent::Types::RedshiftProvisionedAuthConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains configurations for authentication to an Amazon Redshift provisioned data warehouse. Specify the type of authentication to use in the type field and include the corresponding field. If you specify IAM authentication, you don't need to include another field.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#database_userString

The database username for authentication to an Amazon Redshift provisioned data warehouse.

Returns:

  • (String)


9587
9588
9589
9590
9591
9592
9593
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9587

class RedshiftProvisionedAuthConfiguration < Struct.new(
  :type,
  :database_user,
  :username_password_secret_arn)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of authentication to use.

Returns:

  • (String)


9587
9588
9589
9590
9591
9592
9593
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9587

class RedshiftProvisionedAuthConfiguration < Struct.new(
  :type,
  :database_user,
  :username_password_secret_arn)
  SENSITIVE = []
  include Aws::Structure
end

#username_password_secret_arnString

The ARN of an Secrets Manager secret for authentication.

Returns:

  • (String)


9587
9588
9589
9590
9591
9592
9593
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9587

class RedshiftProvisionedAuthConfiguration < Struct.new(
  :type,
  :database_user,
  :username_password_secret_arn)
  SENSITIVE = []
  include Aws::Structure
end