Class: Aws::BedrockAgent::Types::RedshiftQueryEngineStorageConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::RedshiftQueryEngineStorageConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains configurations for Amazon Redshift data storage. Specify the
data storage service to use in the type field and include the
corresponding field. For more information, see Build a knowledge base
by connecting to a structured data source in the Amazon Bedrock
User Guide.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#aws_data_catalog_configuration ⇒ Types::RedshiftQueryEngineAwsDataCatalogStorageConfiguration
Specifies configurations for storage in Glue Data Catalog.
-
#redshift_configuration ⇒ Types::RedshiftQueryEngineRedshiftStorageConfiguration
Specifies configurations for storage in Amazon Redshift.
-
#type ⇒ String
The data storage service to use.
Instance Attribute Details
#aws_data_catalog_configuration ⇒ Types::RedshiftQueryEngineAwsDataCatalogStorageConfiguration
Specifies configurations for storage in Glue Data Catalog.
9700 9701 9702 9703 9704 9705 9706 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9700 class RedshiftQueryEngineStorageConfiguration < Struct.new( :type, :aws_data_catalog_configuration, :redshift_configuration) SENSITIVE = [] include Aws::Structure end |
#redshift_configuration ⇒ Types::RedshiftQueryEngineRedshiftStorageConfiguration
Specifies configurations for storage in Amazon Redshift.
9700 9701 9702 9703 9704 9705 9706 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9700 class RedshiftQueryEngineStorageConfiguration < Struct.new( :type, :aws_data_catalog_configuration, :redshift_configuration) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The data storage service to use.
9700 9701 9702 9703 9704 9705 9706 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9700 class RedshiftQueryEngineStorageConfiguration < Struct.new( :type, :aws_data_catalog_configuration, :redshift_configuration) SENSITIVE = [] include Aws::Structure end |