Class: Aws::BedrockAgent::Types::RetrievalFlowNodeServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Note:

RetrievalFlowNodeServiceConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

RetrievalFlowNodeServiceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RetrievalFlowNodeServiceConfiguration corresponding to the set member.

Contains configurations for the service to use for retrieving data to return as the output from the node.

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Types::RetrievalFlowNodeS3Configuration

Contains configurations for the Amazon S3 location from which to retrieve data to return as the output from the node.



9841
9842
9843
9844
9845
9846
9847
9848
9849
9850
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9841

class RetrievalFlowNodeServiceConfiguration < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < RetrievalFlowNodeServiceConfiguration; end
  class Unknown < RetrievalFlowNodeServiceConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9841
9842
9843
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9841

def unknown
  @unknown
end