Class: Aws::BedrockAgent::Types::S3VectorsConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::S3VectorsConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains the storage configuration of the knowledge base for S3 vectors.
Constant Summary collapse
- SENSITIVE =
[:vector_bucket_arn, :index_arn, :index_name]
Instance Attribute Summary collapse
-
#index_arn ⇒ String
The Amazon Resource Name (ARN) of the vector index used for the knowledge base.
-
#index_name ⇒ String
The name of the vector index used for the knowledge base.
-
#vector_bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 bucket where vector embeddings are stored.
Instance Attribute Details
#index_arn ⇒ String
The Amazon Resource Name (ARN) of the vector index used for the knowledge base. This ARN identifies the specific vector index resource within Amazon Bedrock.
9854 9855 9856 9857 9858 9859 9860 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9854 class S3VectorsConfiguration < Struct.new( :vector_bucket_arn, :index_arn, :index_name) SENSITIVE = [:vector_bucket_arn, :index_arn, :index_name] include Aws::Structure end |
#index_name ⇒ String
The name of the vector index used for the knowledge base. This name identifies the vector index within the Amazon Bedrock service.
9854 9855 9856 9857 9858 9859 9860 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9854 class S3VectorsConfiguration < Struct.new( :vector_bucket_arn, :index_arn, :index_name) SENSITIVE = [:vector_bucket_arn, :index_arn, :index_name] include Aws::Structure end |
#vector_bucket_arn ⇒ String
The Amazon Resource Name (ARN) of the S3 bucket where vector embeddings are stored. This bucket contains the vector data used by the knowledge base.
9854 9855 9856 9857 9858 9859 9860 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9854 class S3VectorsConfiguration < Struct.new( :vector_bucket_arn, :index_arn, :index_name) SENSITIVE = [:vector_bucket_arn, :index_arn, :index_name] include Aws::Structure end |