Class: Aws::BedrockAgent::Types::StartIngestionJobRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#client_tokenString

A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see Ensuring idempotency.

A suitable default value is auto-generated. You should normally not need to pass this option.

Returns:

  • (String)


10201
10202
10203
10204
10205
10206
10207
10208
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10201

class StartIngestionJobRequest < Struct.new(
  :knowledge_base_id,
  :data_source_id,
  :client_token,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#data_source_idString

The unique identifier of the data source you want to ingest into your knowledge base.

Returns:

  • (String)


10201
10202
10203
10204
10205
10206
10207
10208
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10201

class StartIngestionJobRequest < Struct.new(
  :knowledge_base_id,
  :data_source_id,
  :client_token,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#descriptionString

A description of the data ingestion job.

Returns:

  • (String)


10201
10202
10203
10204
10205
10206
10207
10208
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10201

class StartIngestionJobRequest < Struct.new(
  :knowledge_base_id,
  :data_source_id,
  :client_token,
  :description)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier of the knowledge base for the data ingestion job.

Returns:

  • (String)


10201
10202
10203
10204
10205
10206
10207
10208
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10201

class StartIngestionJobRequest < Struct.new(
  :knowledge_base_id,
  :data_source_id,
  :client_token,
  :description)
  SENSITIVE = []
  include Aws::Structure
end