Class: Aws::BedrockAgent::Types::SyncSchedule

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Note:

SyncSchedule is a union - when making an API calls you must set exactly one of the members.

Note:

SyncSchedule is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SyncSchedule corresponding to the set member.

The recurring schedule on which a managed knowledge base connector automatically syncs its data source. Specify exactly one of daily, weekly, or monthly.

Defined Under Namespace

Classes: Daily, Monthly, Unknown, Weekly

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#dailyTypes::DailySchedule

A daily sync that runs once a day at a system-chosen off-peak time. The run time is not configurable.



10564
10565
10566
10567
10568
10569
10570
10571
10572
10573
10574
10575
10576
10577
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10564

class SyncSchedule < Struct.new(
  :daily,
  :weekly,
  :monthly,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Daily < SyncSchedule; end
  class Weekly < SyncSchedule; end
  class Monthly < SyncSchedule; end
  class Unknown < SyncSchedule; end
end

#monthlyTypes::MonthlySchedule

A monthly sync that runs once a month on the specified day of the month.



10564
10565
10566
10567
10568
10569
10570
10571
10572
10573
10574
10575
10576
10577
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10564

class SyncSchedule < Struct.new(
  :daily,
  :weekly,
  :monthly,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Daily < SyncSchedule; end
  class Weekly < SyncSchedule; end
  class Monthly < SyncSchedule; end
  class Unknown < SyncSchedule; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



10564
10565
10566
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10564

def unknown
  @unknown
end

#weeklyTypes::WeeklySchedule

A weekly sync that runs once a week on the specified day of the week.



10564
10565
10566
10567
10568
10569
10570
10571
10572
10573
10574
10575
10576
10577
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10564

class SyncSchedule < Struct.new(
  :daily,
  :weekly,
  :monthly,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Daily < SyncSchedule; end
  class Weekly < SyncSchedule; end
  class Monthly < SyncSchedule; end
  class Unknown < SyncSchedule; end
end