Class: Aws::BedrockAgent::Types::SystemContentBlock
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::SystemContentBlock
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
SystemContentBlock is a union - when making an API calls you must set exactly one of the members.
SystemContentBlock is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of SystemContentBlock corresponding to the set member.
Contains a system prompt to provide context to the model or to describe how it should behave. For more information, see [Create a prompt using Prompt management].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-management-create.html
Direct Known Subclasses
Defined Under Namespace
Classes: CachePoint, Text, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#cache_point ⇒ Types::CachePointBlock
Creates a cache checkpoint within a tool designation.
-
#text ⇒ String
The text in the system prompt.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#cache_point ⇒ Types::CachePointBlock
Creates a cache checkpoint within a tool designation
10456 10457 10458 10459 10460 10461 10462 10463 10464 10465 10466 10467 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10456 class SystemContentBlock < Struct.new( :text, :cache_point, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SystemContentBlock; end class CachePoint < SystemContentBlock; end class Unknown < SystemContentBlock; end end |
#text ⇒ String
The text in the system prompt.
10456 10457 10458 10459 10460 10461 10462 10463 10464 10465 10466 10467 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10456 class SystemContentBlock < Struct.new( :text, :cache_point, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Text < SystemContentBlock; end class CachePoint < SystemContentBlock; end class Unknown < SystemContentBlock; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10456 10457 10458 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10456 def unknown @unknown end |