Class: Aws::BedrockAgent::Types::TextPromptTemplateConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains configurations for a text prompt template. To include a variable, enclose a word in double curly braces as in ‘{variable}`.

Constant Summary collapse

SENSITIVE =
[:text, :input_variables]

Instance Attribute Summary collapse

Instance Attribute Details

#cache_pointTypes::CachePointBlock

A cache checkpoint within a template configuration.



10522
10523
10524
10525
10526
10527
10528
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10522

class TextPromptTemplateConfiguration < Struct.new(
  :text,
  :cache_point,
  :input_variables)
  SENSITIVE = [:text, :input_variables]
  include Aws::Structure
end

#input_variablesArray<Types::PromptInputVariable>

An array of the variables in the prompt template.

Returns:



10522
10523
10524
10525
10526
10527
10528
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10522

class TextPromptTemplateConfiguration < Struct.new(
  :text,
  :cache_point,
  :input_variables)
  SENSITIVE = [:text, :input_variables]
  include Aws::Structure
end

#textString

The message for the prompt.

Returns:

  • (String)


10522
10523
10524
10525
10526
10527
10528
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10522

class TextPromptTemplateConfiguration < Struct.new(
  :text,
  :cache_point,
  :input_variables)
  SENSITIVE = [:text, :input_variables]
  include Aws::Structure
end