Class: Aws::BedrockAgent::Types::ToolChoice
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ToolChoice
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
ToolChoice is a union - when making an API calls you must set exactly one of the members.
ToolChoice is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ToolChoice corresponding to the set member.
Defines which tools the model should request when invoked. For more information, see Use a tool to complete an Amazon Bedrock model response.
Defined Under Namespace
Classes: Any, Auto, Tool, Unknown
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#any ⇒ Types::AnyToolChoice
Defines tools, at least one of which must be requested by the model.
-
#auto ⇒ Types::AutoToolChoice
Defines tools.
-
#tool ⇒ Types::SpecificToolChoice
Defines a specific tool that the model must request.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#any ⇒ Types::AnyToolChoice
Defines tools, at least one of which must be requested by the model. No text is generated but the results of tool use are sent back to the model to help generate a response.
10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 10766 10767 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10754 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#auto ⇒ Types::AutoToolChoice
Defines tools. The model automatically decides whether to call a tool or to generate text instead.
10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 10766 10767 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10754 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#tool ⇒ Types::SpecificToolChoice
Defines a specific tool that the model must request. No text is generated but the results of tool use are sent back to the model to help generate a response.
10754 10755 10756 10757 10758 10759 10760 10761 10762 10763 10764 10765 10766 10767 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10754 class ToolChoice < Struct.new( :auto, :any, :tool, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Auto < ToolChoice; end class Any < ToolChoice; end class Tool < ToolChoice; end class Unknown < ToolChoice; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
10754 10755 10756 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10754 def unknown @unknown end |