Class: Aws::BedrockAgent::Types::ToolConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ToolConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Configuration information for the tools that the model can use when generating a response. For more information, see Use a tool to complete an Amazon Bedrock model response.
Constant Summary collapse
- SENSITIVE =
[:tools, :tool_choice]
Instance Attribute Summary collapse
-
#tool_choice ⇒ Types::ToolChoice
Defines which tools the model should request when invoked.
-
#tools ⇒ Array<Types::Tool>
An array of tools to pass to a model.
Instance Attribute Details
#tool_choice ⇒ Types::ToolChoice
Defines which tools the model should request when invoked.
10787 10788 10789 10790 10791 10792 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10787 class ToolConfiguration < Struct.new( :tools, :tool_choice) SENSITIVE = [:tools, :tool_choice] include Aws::Structure end |
#tools ⇒ Array<Types::Tool>
An array of tools to pass to a model.
10787 10788 10789 10790 10791 10792 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10787 class ToolConfiguration < Struct.new( :tools, :tool_choice) SENSITIVE = [:tools, :tool_choice] include Aws::Structure end |