Class: Aws::BedrockAgent::Types::Transformation

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

A custom processing step for documents moving through a data source ingestion pipeline. To process documents after they have been converted into chunks, set the step to apply to POST_CHUNKING.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#step_to_applyString

When the service applies the transformation.

Returns:

  • (String)


10870
10871
10872
10873
10874
10875
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10870

class Transformation < Struct.new(
  :transformation_function,
  :step_to_apply)
  SENSITIVE = []
  include Aws::Structure
end

#transformation_functionTypes::TransformationFunction

A Lambda function that processes documents.



10870
10871
10872
10873
10874
10875
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10870

class Transformation < Struct.new(
  :transformation_function,
  :step_to_apply)
  SENSITIVE = []
  include Aws::Structure
end