Class: Aws::BedrockAgent::Types::UnfulfilledNodeInputFlowValidationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Details about an unfulfilled node input with no valid connections.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#inputString

The name of the unfulfilled input. An input is unfulfilled if there are no data connections to it.

Returns:

  • (String)


10773
10774
10775
10776
10777
10778
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10773

class UnfulfilledNodeInputFlowValidationDetails < Struct.new(
  :node,
  :input)
  SENSITIVE = []
  include Aws::Structure
end

#nodeString

The name of the node containing the unfulfilled input.

Returns:

  • (String)


10773
10774
10775
10776
10777
10778
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10773

class UnfulfilledNodeInputFlowValidationDetails < Struct.new(
  :node,
  :input)
  SENSITIVE = []
  include Aws::Structure
end