Class: Aws::BedrockAgent::Types::UnknownConnectionTargetFlowValidationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::UnknownConnectionTargetFlowValidationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Details about an unknown target node for a connection.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection ⇒ String
The name of the connection with the unknown target.
Instance Attribute Details
#connection ⇒ String
The name of the connection with the unknown target.
10809 10810 10811 10812 10813 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10809 class UnknownConnectionTargetFlowValidationDetails < Struct.new( :connection) SENSITIVE = [] include Aws::Structure end |