Class: Aws::BedrockAgent::Types::UnknownConnectionTargetInputFlowValidationDetails

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Details about an unknown target input for a connection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#connectionString

The name of the connection with the unknown target input.

Returns:

  • (String)


10844
10845
10846
10847
10848
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10844

class UnknownConnectionTargetInputFlowValidationDetails < Struct.new(
  :connection)
  SENSITIVE = []
  include Aws::Structure
end