Class: Aws::BedrockAgent::Types::UpdateAgentActionGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::UpdateAgentActionGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_group_executor ⇒ Types::ActionGroupExecutor
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action.
-
#action_group_id ⇒ String
The unique identifier of the action group.
-
#action_group_name ⇒ String
Specifies a new name for the action group.
-
#action_group_state ⇒ String
Specifies whether the action group is available for the agent to invoke or not when sending an [InvokeAgent][1] request.
-
#agent_id ⇒ String
The unique identifier of the agent for which to update the action group.
-
#agent_version ⇒ String
The unique identifier of the agent version for which to update the action group.
-
#api_schema ⇒ Types::APISchema
Contains either details about the S3 object containing the OpenAPI schema for the action group or the JSON or YAML-formatted payload defining the schema.
-
#description ⇒ String
Specifies a new name for the action group.
-
#function_schema ⇒ Types::FunctionSchema
Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.
-
#parent_action_group_signature ⇒ String
Update the built-in or computer use action for this action group.
-
#parent_action_group_signature_params ⇒ Hash<String,String>
The configuration settings for a computer use action.
Instance Attribute Details
#action_group_executor ⇒ Types::ActionGroupExecutor
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#action_group_id ⇒ String
The unique identifier of the action group.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#action_group_name ⇒ String
Specifies a new name for the action group.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#action_group_state ⇒ String
Specifies whether the action group is available for the agent to invoke or not when sending an InvokeAgent request.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#agent_id ⇒ String
The unique identifier of the agent for which to update the action group.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#agent_version ⇒ String
The unique identifier of the agent version for which to update the action group.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#api_schema ⇒ Types::APISchema
Contains either details about the S3 object containing the OpenAPI schema for the action group or the JSON or YAML-formatted payload defining the schema. For more information, see Action group OpenAPI schemas.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
Specifies a new name for the action group.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#function_schema ⇒ Types::FunctionSchema
Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#parent_action_group_signature ⇒ String
Update the built-in or computer use action for this action group. If
you specify a value, you must leave the description, apiSchema,
and actionGroupExecutor fields empty for this action group.
-
To allow your agent to request the user for additional information when trying to complete a task, set this field to
AMAZON.UserInput. -
To allow your agent to generate, run, and troubleshoot code when trying to complete a task, set this field to
AMAZON.CodeInterpreter. -
To allow your agent to use an Anthropic computer use tool, specify one of the following values.
Computer use is a new Anthropic Claude model capability (in beta) available with Anthropic Claude 3.7 Sonnet and Claude 3.5 Sonnet v2 only. When operating computer use functionality, we recommend taking additional security precautions, such as executing computer actions in virtual environments with restricted data access and limited internet connectivity. For more information, see Configure an Amazon Bedrock Agent to complete tasks with computer use tools.
-
ANTHROPIC.Computer- Gives the agent permission to use the mouse and keyboard and take screenshots. -
ANTHROPIC.TextEditor- Gives the agent permission to view, create and edit files. -
ANTHROPIC.Bash- Gives the agent permission to run commands in a bash shell.
During orchestration, if your agent determines that it needs to invoke an API in an action group, but doesn't have enough information to complete the API request, it will invoke this action group instead and return an Observation reprompting the user for more information.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |
#parent_action_group_signature_params ⇒ Hash<String,String>
The configuration settings for a computer use action.
Computer use is a new Anthropic Claude model capability (in beta) available with Claude 3.7 Sonnet and Claude 3.5 Sonnet v2 only. For more information, see Configure an Amazon Bedrock Agent to complete tasks with computer use tools.
11206 11207 11208 11209 11210 11211 11212 11213 11214 11215 11216 11217 11218 11219 11220 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11206 class UpdateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :action_group_name, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :action_group_state, :api_schema, :function_schema) SENSITIVE = [] include Aws::Structure end |