Class: Aws::BedrockAgent::Types::UpdateAgentKnowledgeBaseResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::UpdateAgentKnowledgeBaseResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_knowledge_base ⇒ Types::AgentKnowledgeBase
Contains details about the knowledge base that has been associated with an agent.
Instance Attribute Details
#agent_knowledge_base ⇒ Types::AgentKnowledgeBase
Contains details about the knowledge base that has been associated with an agent.
11244 11245 11246 11247 11248 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11244 class UpdateAgentKnowledgeBaseResponse < Struct.new( :agent_knowledge_base) SENSITIVE = [] include Aws::Structure end |