Class: Aws::BedrockAgent::Types::UpdateAgentRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[:instruction, :prompt_override_configuration]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_collaborationString

The agent's collaboration role.

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#agent_idString

The unique identifier of the agent.

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#agent_nameString

Specifies a new name for the agent.

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#agent_resource_role_arnString

The Amazon Resource Name (ARN) of the IAM role with permissions to invoke API operations on the agent.

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#custom_orchestrationTypes::CustomOrchestration

Contains details of the custom orchestration configured for the agent.



11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#customer_encryption_key_arnString

The Amazon Resource Name (ARN) of the KMS key with which to encrypt the agent.

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#descriptionString

Specifies a new description of the agent.

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#foundation_modelString

The identifier for the model that you want to be used for orchestration by the agent you create.

The modelId to provide depends on the type of model or throughput that you use:

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#guardrail_configurationTypes::GuardrailConfiguration

The unique Guardrail configuration assigned to the agent when it is updated.



11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#idle_session_ttl_in_secondsInteger

The number of seconds for which Amazon Bedrock keeps information about a user's conversation with the agent.

A user interaction remains active for the amount of time specified. If no conversation occurs during this time, the session expires and Amazon Bedrock deletes any data provided before the timeout.

Returns:

  • (Integer)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#instructionString

Specifies new instructions that tell the agent what it should do and how it should interact with users.

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#memory_configurationTypes::MemoryConfiguration

Specifies the new memory configuration for the agent.



11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#orchestration_typeString

Specifies the type of orchestration strategy for the agent. This is set to DEFAULT orchestration type, by default.

Returns:

  • (String)


11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end

#prompt_override_configurationTypes::PromptOverrideConfiguration

Contains configurations to override prompts in different parts of an agent sequence. For more information, see Advanced prompts.



11505
11506
11507
11508
11509
11510
11511
11512
11513
11514
11515
11516
11517
11518
11519
11520
11521
11522
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11505

class UpdateAgentRequest < Struct.new(
  :agent_id,
  :agent_name,
  :instruction,
  :foundation_model,
  :description,
  :orchestration_type,
  :custom_orchestration,
  :idle_session_ttl_in_seconds,
  :agent_resource_role_arn,
  :customer_encryption_key_arn,
  :prompt_override_configuration,
  :guardrail_configuration,
  :memory_configuration,
  :agent_collaboration)
  SENSITIVE = [:instruction, :prompt_override_configuration]
  include Aws::Structure
end