Class: Aws::BedrockAgent::Types::UpdateFlowResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::UpdateFlowResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:definition]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the flow.
-
#created_at ⇒ Time
The time at which the flow was created.
-
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key that the flow was encrypted with.
-
#definition ⇒ Types::FlowDefinition
A definition of the nodes and the connections between nodes in the flow.
-
#description ⇒ String
The description of the flow.
-
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the service role with permissions to create a flow.
-
#id ⇒ String
The unique identifier of the flow.
-
#name ⇒ String
The name of the flow.
-
#status ⇒ String
The status of the flow.
-
#updated_at ⇒ Time
The time at which the flow was last updated.
-
#version ⇒ String
The version of the flow.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the flow.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#created_at ⇒ Time
The time at which the flow was created.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key that the flow was encrypted with.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#definition ⇒ Types::FlowDefinition
A definition of the nodes and the connections between nodes in the flow.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#description ⇒ String
The description of the flow.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#execution_role_arn ⇒ String
The Amazon Resource Name (ARN) of the service role with permissions to create a flow. For more information, see Create a service role for flows in Amazon Bedrock in the Amazon Bedrock User Guide.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#id ⇒ String
The unique identifier of the flow.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#name ⇒ String
The name of the flow.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#status ⇒ String
The status of the flow. When you submit this request, the status
will be NotPrepared. If updating fails, the status becomes
Failed.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#updated_at ⇒ Time
The time at which the flow was last updated.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |
#version ⇒ String
The version of the flow. When you update a flow, the version updated
is the DRAFT version.
11791 11792 11793 11794 11795 11796 11797 11798 11799 11800 11801 11802 11803 11804 11805 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11791 class UpdateFlowResponse < Struct.new( :name, :description, :execution_role_arn, :customer_encryption_key_arn, :id, :arn, :status, :created_at, :updated_at, :version, :definition) SENSITIVE = [:definition] include Aws::Structure end |