Class: Aws::BedrockAgent::Types::UpdateKnowledgeBaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

Specifies a new description for the knowledge base.

Returns:

  • (String)


11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_configurationTypes::KnowledgeBaseConfiguration

Specifies the configuration for the embeddings model used for the knowledge base. You must use the same configuration as when the knowledge base was created.



11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier of the knowledge base to update.

Returns:

  • (String)


11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Specifies a new name for the knowledge base.

Returns:

  • (String)


11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Specifies a different Amazon Resource Name (ARN) of the IAM role with permissions to invoke API operations on the knowledge base.

Returns:

  • (String)


11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#storage_configurationTypes::StorageConfiguration

Specifies the configuration for the vector store used for the knowledge base. You must use the same configuration as when the knowledge base was created.



11838
11839
11840
11841
11842
11843
11844
11845
11846
11847
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end