Class: Aws::BedrockAgent::Types::UpdatePromptRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::UpdatePromptRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:variants]
Instance Attribute Summary collapse
-
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key to encrypt the prompt.
-
#default_variant ⇒ String
The name of the default variant for the prompt.
-
#description ⇒ String
A description for the prompt.
-
#name ⇒ String
A name for the prompt.
-
#prompt_identifier ⇒ String
The unique identifier of the prompt.
-
#variants ⇒ Array<Types::PromptVariant>
A list of objects, each containing details about a variant of the prompt.
Instance Attribute Details
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key to encrypt the prompt.
11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11893 class UpdatePromptRequest < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :prompt_identifier) SENSITIVE = [:variants] include Aws::Structure end |
#default_variant ⇒ String
The name of the default variant for the prompt. This value must
match the name field in the relevant PromptVariant object.
11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11893 class UpdatePromptRequest < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :prompt_identifier) SENSITIVE = [:variants] include Aws::Structure end |
#description ⇒ String
A description for the prompt.
11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11893 class UpdatePromptRequest < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :prompt_identifier) SENSITIVE = [:variants] include Aws::Structure end |
#name ⇒ String
A name for the prompt.
11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11893 class UpdatePromptRequest < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :prompt_identifier) SENSITIVE = [:variants] include Aws::Structure end |
#prompt_identifier ⇒ String
The unique identifier of the prompt.
11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11893 class UpdatePromptRequest < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :prompt_identifier) SENSITIVE = [:variants] include Aws::Structure end |
#variants ⇒ Array<Types::PromptVariant>
A list of objects, each containing details about a variant of the prompt.
11893 11894 11895 11896 11897 11898 11899 11900 11901 11902 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11893 class UpdatePromptRequest < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :prompt_identifier) SENSITIVE = [:variants] include Aws::Structure end |