Class: Aws::BedrockAgent::Types::UpdatePromptResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::UpdatePromptResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:variants]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the prompt.
-
#created_at ⇒ Time
The time at which the prompt was created.
-
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key to encrypt the prompt.
-
#default_variant ⇒ String
The name of the default variant for the prompt.
-
#description ⇒ String
The description of the prompt.
-
#id ⇒ String
The unique identifier of the prompt.
-
#name ⇒ String
The name of the prompt.
-
#updated_at ⇒ Time
The time at which the prompt was last updated.
-
#variants ⇒ Array<Types::PromptVariant>
A list of objects, each containing details about a variant of the prompt.
-
#version ⇒ String
The version of the prompt.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the prompt.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#created_at ⇒ Time
The time at which the prompt was created.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key to encrypt the prompt.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#default_variant ⇒ String
The name of the default variant for the prompt. This value must
match the name field in the relevant PromptVariant object.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#description ⇒ String
The description of the prompt.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#id ⇒ String
The unique identifier of the prompt.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#name ⇒ String
The name of the prompt.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#updated_at ⇒ Time
The time at which the prompt was last updated.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#variants ⇒ Array<Types::PromptVariant>
A list of objects, each containing details about a variant of the prompt.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#version ⇒ String
The version of the prompt. When you update a prompt, the version
updated is the DRAFT version.
11808 11809 11810 11811 11812 11813 11814 11815 11816 11817 11818 11819 11820 11821 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11808 class UpdatePromptResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |