Class: Aws::BedrockAgent::Types::BedrockEmbeddingModelConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

The vector configuration details for the Bedrock embeddings model.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#audioArray<Types::AudioConfiguration>

Configuration settings for processing audio content in multimodal knowledge bases.

Returns:



1313
1314
1315
1316
1317
1318
1319
1320
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1313

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video)
  SENSITIVE = []
  include Aws::Structure
end

#dimensionsInteger

The dimensions details for the vector configuration used on the Bedrock embeddings model.

Returns:

  • (Integer)


1313
1314
1315
1316
1317
1318
1319
1320
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1313

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video)
  SENSITIVE = []
  include Aws::Structure
end

#embedding_data_typeString

The data type for the vectors when using a model to convert text into vector embeddings. The model must support the specified data type for vector embeddings. Floating-point (float32) is the default data type, and is supported by most models for vector embeddings. See Supported embeddings models for information on the available models and their vector data types.

Returns:

  • (String)


1313
1314
1315
1316
1317
1318
1319
1320
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1313

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video)
  SENSITIVE = []
  include Aws::Structure
end

#videoArray<Types::VideoConfiguration>

Configuration settings for processing video content in multimodal knowledge bases.

Returns:



1313
1314
1315
1316
1317
1318
1319
1320
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1313

class BedrockEmbeddingModelConfiguration < Struct.new(
  :dimensions,
  :embedding_data_type,
  :audio,
  :video)
  SENSITIVE = []
  include Aws::Structure
end