Class: Aws::BedrockAgent::Types::BedrockEmbeddingModelConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::BedrockEmbeddingModelConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
The vector configuration details for the Bedrock embeddings model.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#audio ⇒ Array<Types::AudioConfiguration>
Configuration settings for processing audio content in multimodal knowledge bases.
-
#dimensions ⇒ Integer
The dimensions details for the vector configuration used on the Bedrock embeddings model.
-
#embedding_data_type ⇒ String
The data type for the vectors when using a model to convert text into vector embeddings.
-
#model_configuration ⇒ Hash, ...
Model-specific configuration for the embedding model, provided as a JSON object.
-
#video ⇒ Array<Types::VideoConfiguration>
Configuration settings for processing video content in multimodal knowledge bases.
Instance Attribute Details
#audio ⇒ Array<Types::AudioConfiguration>
Configuration settings for processing audio content in multimodal knowledge bases.
This field is deprecated. Use modelConfiguration instead.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328 class BedrockEmbeddingModelConfiguration < Struct.new( :dimensions, :embedding_data_type, :audio, :video, :model_configuration) SENSITIVE = [] include Aws::Structure end |
#dimensions ⇒ Integer
The dimensions details for the vector configuration used on the Bedrock embeddings model.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328 class BedrockEmbeddingModelConfiguration < Struct.new( :dimensions, :embedding_data_type, :audio, :video, :model_configuration) SENSITIVE = [] include Aws::Structure end |
#embedding_data_type ⇒ String
The data type for the vectors when using a model to convert text into vector embeddings. The model must support the specified data type for vector embeddings. Floating-point (float32) is the default data type, and is supported by most models for vector embeddings. See Supported embeddings models for information on the available models and their vector data types.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328 class BedrockEmbeddingModelConfiguration < Struct.new( :dimensions, :embedding_data_type, :audio, :video, :model_configuration) SENSITIVE = [] include Aws::Structure end |
#model_configuration ⇒ Hash, ...
Model-specific configuration for the embedding model, provided as a JSON object. Use this field to specify settings that apply to the embedding model that you selected, such as how audio and video files are divided into segments.
The fields that this object accepts depend on the embedding model. For the settings that each model accepts, see the documentation for that model.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328 class BedrockEmbeddingModelConfiguration < Struct.new( :dimensions, :embedding_data_type, :audio, :video, :model_configuration) SENSITIVE = [] include Aws::Structure end |
#video ⇒ Array<Types::VideoConfiguration>
Configuration settings for processing video content in multimodal knowledge bases.
This field is deprecated. Use modelConfiguration instead.
1328 1329 1330 1331 1332 1333 1334 1335 1336 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1328 class BedrockEmbeddingModelConfiguration < Struct.new( :dimensions, :embedding_data_type, :audio, :video, :model_configuration) SENSITIVE = [] include Aws::Structure end |