Class: Aws::BedrockAgent::Types::CreateAgentActionGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::CreateAgentActionGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_group_executor ⇒ Types::ActionGroupExecutor
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action or the custom control method for handling the information elicited from the user.
-
#action_group_name ⇒ String
The name to give the action group.
-
#action_group_state ⇒ String
Specifies whether the action group is available for the agent to invoke or not when sending an [InvokeAgent] request.
-
#agent_id ⇒ String
The unique identifier of the agent for which to create the action group.
-
#agent_version ⇒ String
The version of the agent for which to create the action group.
-
#api_schema ⇒ Types::APISchema
Contains either details about the S3 object containing the OpenAPI schema for the action group or the JSON or YAML-formatted payload defining the schema.
-
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than one time.
-
#description ⇒ String
A description of the action group.
-
#function_schema ⇒ Types::FunctionSchema
Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.
-
#parent_action_group_signature ⇒ String
Specify a built-in or computer use action for this action group.
-
#parent_action_group_signature_params ⇒ Hash<String,String>
The configuration settings for a computer use action.
Instance Attribute Details
#action_group_executor ⇒ Types::ActionGroupExecutor
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action or the custom control method for handling the information elicited from the user.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#action_group_name ⇒ String
The name to give the action group.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#action_group_state ⇒ String
Specifies whether the action group is available for the agent to invoke or not when sending an [InvokeAgent] request.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_InvokeAgent.html
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#agent_id ⇒ String
The unique identifier of the agent for which to create the action group.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#agent_version ⇒ String
The version of the agent for which to create the action group.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#api_schema ⇒ Types::APISchema
Contains either details about the S3 object containing the OpenAPI schema for the action group or the JSON or YAML-formatted payload defining the schema. For more information, see [Action group OpenAPI schemas].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-api-schema.html
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#client_token ⇒ String
A unique, case-sensitive identifier to ensure that the API request completes no more than one time. If this token matches a previous request, Amazon Bedrock ignores the request, but does not return an error. For more information, see [Ensuring idempotency].
**A suitable default value is auto-generated.** You should normally not need to pass this option.
[1]: docs.aws.amazon.com/AWSEC2/latest/APIReference/Run_Instance_Idempotency.html
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the action group.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#function_schema ⇒ Types::FunctionSchema
Contains details about the function schema for the action group or the JSON or YAML-formatted payload defining the schema.
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#parent_action_group_signature ⇒ String
Specify a built-in or computer use action for this action group. If you specify a value, you must leave the ‘description`, `apiSchema`, and `actionGroupExecutor` fields empty for this action group.
-
To allow your agent to request the user for additional information when trying to complete a task, set this field to ‘AMAZON.UserInput`.
-
To allow your agent to generate, run, and troubleshoot code when trying to complete a task, set this field to ‘AMAZON.CodeInterpreter`.
-
To allow your agent to use an Anthropic computer use tool, specify one of the following values.
Computer use is a new Anthropic Claude model capability (in beta) available with Anthropic Claude 3.7 Sonnet and Claude 3.5 Sonnet v2 only. When operating computer use functionality, we recommend taking additional security precautions, such as executing computer actions in virtual environments with restricted data access and limited internet connectivity. For more information, see [Configure an Amazon Bedrock Agent to complete tasks with computer use tools].
-
‘ANTHROPIC.Computer` - Gives the agent permission to use the mouse and keyboard and take screenshots.
-
‘ANTHROPIC.TextEditor` - Gives the agent permission to view, create and edit files.
-
‘ANTHROPIC.Bash` - Gives the agent permission to run commands in a bash shell.
-
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-computer-use.html
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |
#parent_action_group_signature_params ⇒ Hash<String,String>
The configuration settings for a computer use action.
Computer use is a new Anthropic Claude model capability (in beta) available with Anthropic Claude 3.7 Sonnet and Claude 3.5 Sonnet v2 only. For more information, see [Configure an Amazon Bedrock Agent to complete tasks with computer use tools].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/agents-computer-use.html
1868 1869 1870 1871 1872 1873 1874 1875 1876 1877 1878 1879 1880 1881 1882 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 1868 class CreateAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_name, :client_token, :description, :parent_action_group_signature, :parent_action_group_signature_params, :action_group_executor, :api_schema, :action_group_state, :function_schema) SENSITIVE = [] include Aws::Structure end |