Class: Aws::BedrockAgent::Types::CreatePromptVersionResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::CreatePromptVersionResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:variants]
Instance Attribute Summary collapse
-
#arn ⇒ String
The Amazon Resource Name (ARN) of the version of the prompt.
-
#created_at ⇒ Time
The time at which the prompt was created.
-
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key to encrypt the version of the prompt.
-
#default_variant ⇒ String
The name of the default variant for the prompt.
-
#description ⇒ String
A description for the version.
-
#id ⇒ String
The unique identifier of the prompt.
-
#name ⇒ String
The name of the prompt.
-
#updated_at ⇒ Time
The time at which the prompt was last updated.
-
#variants ⇒ Array<Types::PromptVariant>
A list of objects, each containing details about a variant of the prompt.
-
#version ⇒ String
The version of the prompt that was created.
Instance Attribute Details
#arn ⇒ String
The Amazon Resource Name (ARN) of the version of the prompt.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#created_at ⇒ Time
The time at which the prompt was created.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#customer_encryption_key_arn ⇒ String
The Amazon Resource Name (ARN) of the KMS key to encrypt the version of the prompt.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#default_variant ⇒ String
The name of the default variant for the prompt. This value must
match the name field in the relevant PromptVariant object.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#description ⇒ String
A description for the version.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#id ⇒ String
The unique identifier of the prompt.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#name ⇒ String
The name of the prompt.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#updated_at ⇒ Time
The time at which the prompt was last updated.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#variants ⇒ Array<Types::PromptVariant>
A list of objects, each containing details about a variant of the prompt.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |
#version ⇒ String
The version of the prompt that was created. Versions are numbered incrementally, starting from 1.
2845 2846 2847 2848 2849 2850 2851 2852 2853 2854 2855 2856 2857 2858 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 2845 class CreatePromptVersionResponse < Struct.new( :name, :description, :customer_encryption_key_arn, :default_variant, :variants, :id, :arn, :version, :created_at, :updated_at) SENSITIVE = [:variants] include Aws::Structure end |