Class: Aws::BedrockAgent::Types::DeleteAgentActionGroupRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DeleteAgentActionGroupRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#action_group_id ⇒ String
The unique identifier of the action group to delete.
-
#agent_id ⇒ String
The unique identifier of the agent that the action group belongs to.
-
#agent_version ⇒ String
The version of the agent that the action group belongs to.
-
#skip_resource_in_use_check ⇒ Boolean
By default, this value is
falseand deletion is stopped if the resource is in use.
Instance Attribute Details
#action_group_id ⇒ String
The unique identifier of the action group to delete.
3285 3286 3287 3288 3289 3290 3291 3292 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3285 class DeleteAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#agent_id ⇒ String
The unique identifier of the agent that the action group belongs to.
3285 3286 3287 3288 3289 3290 3291 3292 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3285 class DeleteAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#agent_version ⇒ String
The version of the agent that the action group belongs to.
3285 3286 3287 3288 3289 3290 3291 3292 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3285 class DeleteAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#skip_resource_in_use_check ⇒ Boolean
By default, this value is false and deletion is stopped if the
resource is in use. If you set it to true, the resource will be
deleted even if the resource is in use.
3285 3286 3287 3288 3289 3290 3291 3292 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3285 class DeleteAgentActionGroupRequest < Struct.new( :agent_id, :agent_version, :action_group_id, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |