Class: Aws::BedrockAgent::Types::DeleteAgentVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#agent_idString

The unique identifier of the agent that the version belongs to.

Returns:

  • (String)


3332
3333
3334
3335
3336
3337
3338
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3332

class DeleteAgentVersionRequest < Struct.new(
  :agent_id,
  :agent_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#agent_versionString

The version of the agent to delete.

Returns:

  • (String)


3332
3333
3334
3335
3336
3337
3338
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3332

class DeleteAgentVersionRequest < Struct.new(
  :agent_id,
  :agent_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_resource_in_use_checkBoolean

By default, this value is false and deletion is stopped if the resource is in use. If you set it to true, the resource will be deleted even if the resource is in use.

Returns:

  • (Boolean)


3332
3333
3334
3335
3336
3337
3338
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3332

class DeleteAgentVersionRequest < Struct.new(
  :agent_id,
  :agent_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end