Class: Aws::BedrockAgent::Types::DeleteAgentVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DeleteAgentVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#agent_id ⇒ String
The unique identifier of the agent that the version belongs to.
-
#agent_version ⇒ String
The version of the agent to delete.
-
#skip_resource_in_use_check ⇒ Boolean
By default, this value is
falseand deletion is stopped if the resource is in use.
Instance Attribute Details
#agent_id ⇒ String
The unique identifier of the agent that the version belongs to.
3332 3333 3334 3335 3336 3337 3338 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3332 class DeleteAgentVersionRequest < Struct.new( :agent_id, :agent_version, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#agent_version ⇒ String
The version of the agent to delete.
3332 3333 3334 3335 3336 3337 3338 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3332 class DeleteAgentVersionRequest < Struct.new( :agent_id, :agent_version, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#skip_resource_in_use_check ⇒ Boolean
By default, this value is false and deletion is stopped if the
resource is in use. If you set it to true, the resource will be
deleted even if the resource is in use.
3332 3333 3334 3335 3336 3337 3338 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3332 class DeleteAgentVersionRequest < Struct.new( :agent_id, :agent_version, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |