Class: Aws::BedrockAgent::Types::DeleteFlowVersionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#flow_identifierString

The unique identifier of the flow whose version that you want to delete

Returns:

  • (String)


3485
3486
3487
3488
3489
3490
3491
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3485

class DeleteFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#flow_versionString

The version of the flow that you want to delete.

Returns:

  • (String)


3485
3486
3487
3488
3489
3490
3491
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3485

class DeleteFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end

#skip_resource_in_use_checkBoolean

By default, this value is false and deletion is stopped if the resource is in use. If you set it to true, the resource will be deleted even if the resource is in use.

Returns:

  • (Boolean)


3485
3486
3487
3488
3489
3490
3491
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3485

class DeleteFlowVersionRequest < Struct.new(
  :flow_identifier,
  :flow_version,
  :skip_resource_in_use_check)
  SENSITIVE = []
  include Aws::Structure
end