Class: Aws::BedrockAgent::Types::DeleteFlowVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DeleteFlowVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_identifier ⇒ String
The unique identifier of the flow whose version that you want to delete.
-
#flow_version ⇒ String
The version of the flow that you want to delete.
-
#skip_resource_in_use_check ⇒ Boolean
By default, this value is
falseand deletion is stopped if the resource is in use.
Instance Attribute Details
#flow_identifier ⇒ String
The unique identifier of the flow whose version that you want to delete
3485 3486 3487 3488 3489 3490 3491 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3485 class DeleteFlowVersionRequest < Struct.new( :flow_identifier, :flow_version, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#flow_version ⇒ String
The version of the flow that you want to delete.
3485 3486 3487 3488 3489 3490 3491 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3485 class DeleteFlowVersionRequest < Struct.new( :flow_identifier, :flow_version, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |
#skip_resource_in_use_check ⇒ Boolean
By default, this value is false and deletion is stopped if the
resource is in use. If you set it to true, the resource will be
deleted even if the resource is in use.
3485 3486 3487 3488 3489 3490 3491 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3485 class DeleteFlowVersionRequest < Struct.new( :flow_identifier, :flow_version, :skip_resource_in_use_check) SENSITIVE = [] include Aws::Structure end |