Class: Aws::BedrockAgent::Types::DeleteResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DeleteResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_revision_id ⇒ String
The expected revision identifier of the resource policy.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base to remove the resource policy from.
Instance Attribute Details
#expected_revision_id ⇒ String
The expected revision identifier of the resource policy. Use this to prevent conflicts when multiple users update the same policy concurrently.
3641 3642 3643 3644 3645 3646 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3641 class DeleteResourcePolicyRequest < Struct.new( :resource_arn, :expected_revision_id) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base to remove the resource policy from.
3641 3642 3643 3644 3645 3646 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3641 class DeleteResourcePolicyRequest < Struct.new( :resource_arn, :expected_revision_id) SENSITIVE = [] include Aws::Structure end |