Class: Aws::BedrockAgent::Types::DeletionProtectionConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Configuration for deletion protection.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#deletion_protection_statusString

Enable or disable deletion protection for the connector.

Returns:

  • (String)


3681
3682
3683
3684
3685
3686
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3681

class DeletionProtectionConfiguration < Struct.new(
  :deletion_protection_status,
  :deletion_protection_threshold)
  SENSITIVE = []
  include Aws::Structure
end

#deletion_protection_thresholdInteger

The threshold is the maximum percentage of documents that a sync job can delete from your index. If a sync would delete more than this percentage, the sync skips its delete phase, leaving your indexed documents in place. Not supported for the Custom connector.

Returns:

  • (Integer)


3681
3682
3683
3684
3685
3686
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3681

class DeletionProtectionConfiguration < Struct.new(
  :deletion_protection_status,
  :deletion_protection_threshold)
  SENSITIVE = []
  include Aws::Structure
end