Class: Aws::BedrockAgent::Types::DocumentMetadata

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains information about the metadata associate with the content to ingest into a knowledge base. Choose a ‘type` and include the field that corresponds to it.

Constant Summary collapse

SENSITIVE =
[:access_control_list]

Instance Attribute Summary collapse

Instance Attribute Details

#access_control_listArray<Types::DocumentAccessControlEntry>

Access control list for the document. Used when metadata type is IN_LINE_ATTRIBUTE.



3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3847

class DocumentMetadata < Struct.new(
  :type,
  :inline_attributes,
  :s3_location,
  :access_control_list)
  SENSITIVE = [:access_control_list]
  include Aws::Structure
end

#inline_attributesArray<Types::MetadataAttribute>

An array of objects, each of which defines a metadata attribute to associate with the content to ingest. You define the attributes inline.

Returns:



3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3847

class DocumentMetadata < Struct.new(
  :type,
  :inline_attributes,
  :s3_location,
  :access_control_list)
  SENSITIVE = [:access_control_list]
  include Aws::Structure
end

#s3_locationTypes::CustomS3Location

The Amazon S3 location of the file containing metadata to associate with the content to ingest.



3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3847

class DocumentMetadata < Struct.new(
  :type,
  :inline_attributes,
  :s3_location,
  :access_control_list)
  SENSITIVE = [:access_control_list]
  include Aws::Structure
end

#typeString

The type of the source source from which to add metadata.

Returns:

  • (String)


3847
3848
3849
3850
3851
3852
3853
3854
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3847

class DocumentMetadata < Struct.new(
  :type,
  :inline_attributes,
  :s3_location,
  :access_control_list)
  SENSITIVE = [:access_control_list]
  include Aws::Structure
end