Class: Aws::BedrockAgent::Types::DocumentMetadata
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::DocumentMetadata
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains information about the metadata associate with the content to ingest into a knowledge base. Choose a ‘type` and include the field that corresponds to it.
Constant Summary collapse
- SENSITIVE =
[:access_control_list]
Instance Attribute Summary collapse
-
#access_control_list ⇒ Array<Types::DocumentAccessControlEntry>
Access control list for the document.
-
#inline_attributes ⇒ Array<Types::MetadataAttribute>
An array of objects, each of which defines a metadata attribute to associate with the content to ingest.
-
#s3_location ⇒ Types::CustomS3Location
The Amazon S3 location of the file containing metadata to associate with the content to ingest.
-
#type ⇒ String
The type of the source source from which to add metadata.
Instance Attribute Details
#access_control_list ⇒ Array<Types::DocumentAccessControlEntry>
Access control list for the document. Used when metadata type is IN_LINE_ATTRIBUTE.
3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3847 class DocumentMetadata < Struct.new( :type, :inline_attributes, :s3_location, :access_control_list) SENSITIVE = [:access_control_list] include Aws::Structure end |
#inline_attributes ⇒ Array<Types::MetadataAttribute>
An array of objects, each of which defines a metadata attribute to associate with the content to ingest. You define the attributes inline.
3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3847 class DocumentMetadata < Struct.new( :type, :inline_attributes, :s3_location, :access_control_list) SENSITIVE = [:access_control_list] include Aws::Structure end |
#s3_location ⇒ Types::CustomS3Location
The Amazon S3 location of the file containing metadata to associate with the content to ingest.
3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3847 class DocumentMetadata < Struct.new( :type, :inline_attributes, :s3_location, :access_control_list) SENSITIVE = [:access_control_list] include Aws::Structure end |
#type ⇒ String
The type of the source source from which to add metadata.
3847 3848 3849 3850 3851 3852 3853 3854 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 3847 class DocumentMetadata < Struct.new( :type, :inline_attributes, :s3_location, :access_control_list) SENSITIVE = [:access_control_list] include Aws::Structure end |