Class: Aws::BedrockAgent::Types::FlowCondition
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::FlowCondition
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Defines a condition in the condition node.
Constant Summary collapse
- SENSITIVE =
[:expression]
Instance Attribute Summary collapse
-
#expression ⇒ String
Defines the condition.
-
#name ⇒ String
A name for the condition that you can reference.
Instance Attribute Details
#expression ⇒ String
Defines the condition. You must refer to at least one of the inputs in the condition. For more information, expand the Condition node section in Node types in prompt flows.
4086 4087 4088 4089 4090 4091 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4086 class FlowCondition < Struct.new( :name, :expression) SENSITIVE = [:expression] include Aws::Structure end |
#name ⇒ String
A name for the condition that you can reference.
4086 4087 4088 4089 4090 4091 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4086 class FlowCondition < Struct.new( :name, :expression) SENSITIVE = [:expression] include Aws::Structure end |