Class: Aws::BedrockAgent::Types::FlowNode
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::FlowNode
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains configurations about a node in the flow.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#configuration ⇒ Types::FlowNodeConfiguration
Contains configurations for the node.
-
#inputs ⇒ Array<Types::FlowNodeInput>
An array of objects, each of which contains information about an input into the node.
-
#name ⇒ String
A name for the node.
-
#outputs ⇒ Array<Types::FlowNodeOutput>
A list of objects, each of which contains information about an output from the node.
-
#type ⇒ String
The type of node.
Instance Attribute Details
#configuration ⇒ Types::FlowNodeConfiguration
Contains configurations for the node.
4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4248 class FlowNode < Struct.new( :name, :type, :configuration, :inputs, :outputs) SENSITIVE = [] include Aws::Structure end |
#inputs ⇒ Array<Types::FlowNodeInput>
An array of objects, each of which contains information about an input into the node.
4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4248 class FlowNode < Struct.new( :name, :type, :configuration, :inputs, :outputs) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the node.
4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4248 class FlowNode < Struct.new( :name, :type, :configuration, :inputs, :outputs) SENSITIVE = [] include Aws::Structure end |
#outputs ⇒ Array<Types::FlowNodeOutput>
A list of objects, each of which contains information about an output from the node.
4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4248 class FlowNode < Struct.new( :name, :type, :configuration, :inputs, :outputs) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of node. This value must match the name of the key that you
provide in the configuration you provide in the
FlowNodeConfiguration field.
4248 4249 4250 4251 4252 4253 4254 4255 4256 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4248 class FlowNode < Struct.new( :name, :type, :configuration, :inputs, :outputs) SENSITIVE = [] include Aws::Structure end |