Class: Aws::BedrockAgent::Types::Function
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::Function
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Defines parameters that the agent needs to invoke from the user to complete the function. Corresponds to an action in an action group.
This data type is used in the following API operations:
- CreateAgentActionGroup request][1
- CreateAgentActionGroup response][2
- UpdateAgentActionGroup request][3
- UpdateAgentActionGroup response][4
- GetAgentActionGroup response][5
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_CreateAgentActionGroup.html#API_agent_CreateAgentActionGroup_RequestSyntax [2]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_CreateAgentActionGroup.html#API_agent_CreateAgentActionGroup_ResponseSyntax [3]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_UpdateAgentActionGroup.html#API_agent_UpdateAgentActionGroup_RequestSyntax [4]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_UpdateAgentActionGroup.html#API_agent_UpdateAgentActionGroup_ResponseSyntax [5]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_GetAgentActionGroup.html#API_agent_GetAgentActionGroup_ResponseSyntax
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
A description of the function and its purpose.
-
#name ⇒ String
A name for the function.
-
#parameters ⇒ Hash<String,Types::ParameterDetail>
The parameters that the agent elicits from the user to fulfill the function.
-
#require_confirmation ⇒ String
Contains information if user confirmation is required to invoke the function.
Instance Attribute Details
#description ⇒ String
A description of the function and its purpose.
4889 4890 4891 4892 4893 4894 4895 4896 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4889 class Function < Struct.new( :name, :description, :parameters, :require_confirmation) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
A name for the function.
4889 4890 4891 4892 4893 4894 4895 4896 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4889 class Function < Struct.new( :name, :description, :parameters, :require_confirmation) SENSITIVE = [] include Aws::Structure end |
#parameters ⇒ Hash<String,Types::ParameterDetail>
The parameters that the agent elicits from the user to fulfill the function.
4889 4890 4891 4892 4893 4894 4895 4896 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4889 class Function < Struct.new( :name, :description, :parameters, :require_confirmation) SENSITIVE = [] include Aws::Structure end |
#require_confirmation ⇒ String
Contains information if user confirmation is required to invoke the function.
4889 4890 4891 4892 4893 4894 4895 4896 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4889 class Function < Struct.new( :name, :description, :parameters, :require_confirmation) SENSITIVE = [] include Aws::Structure end |