Class: Aws::BedrockAgent::Types::FunctionSchema
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::FunctionSchema
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Note:
FunctionSchema is a union - when making an API calls you must set exactly one of the members.
Note:
FunctionSchema is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of FunctionSchema corresponding to the set member.
Defines functions that each define parameters that the agent needs to invoke from the user. Each function represents an action in an action group.
This data type is used in the following API operations:
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#functions ⇒ Array<Types::Function>
A list of functions that each define an action in the action group.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#functions ⇒ Array<Types::Function>
A list of functions that each define an action in the action group.
4989 4990 4991 4992 4993 4994 4995 4996 4997 4998 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4989 class FunctionSchema < Struct.new( :functions, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Functions < FunctionSchema; end class Unknown < FunctionSchema; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
4989 4990 4991 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 4989 def unknown @unknown end |