Class: Aws::BedrockAgent::Types::GetFlowVersionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::GetFlowVersionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_identifier ⇒ String
The unique identifier of the flow for which to get information.
-
#flow_version ⇒ String
The version of the flow for which to get information.
-
#included_data ⇒ String
Controls the scope of data returned.
Instance Attribute Details
#flow_identifier ⇒ String
The unique identifier of the flow for which to get information.
5364 5365 5366 5367 5368 5369 5370 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5364 class GetFlowVersionRequest < Struct.new( :flow_identifier, :flow_version, :included_data) SENSITIVE = [] include Aws::Structure end |
#flow_version ⇒ String
The version of the flow for which to get information.
5364 5365 5366 5367 5368 5369 5370 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5364 class GetFlowVersionRequest < Struct.new( :flow_identifier, :flow_version, :included_data) SENSITIVE = [] include Aws::Structure end |
#included_data ⇒ String
Controls the scope of data returned. Set to ‘METADATA_ONLY` to return only resource metadata. Set to `ALL_DATA` or omit this field to return the full response.
5364 5365 5366 5367 5368 5369 5370 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5364 class GetFlowVersionRequest < Struct.new( :flow_identifier, :flow_version, :included_data) SENSITIVE = [] include Aws::Structure end |