Class: Aws::BedrockAgent::Types::GetPromptRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#included_dataString

Controls the scope of data returned. Set to ‘METADATA_ONLY` to return only resource metadata. Set to `ALL_DATA` or omit this field to return the full response.

Returns:

  • (String)


5555
5556
5557
5558
5559
5560
5561
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5555

class GetPromptRequest < Struct.new(
  :prompt_identifier,
  :prompt_version,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_identifierString

The unique identifier of the prompt.

Returns:

  • (String)


5555
5556
5557
5558
5559
5560
5561
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5555

class GetPromptRequest < Struct.new(
  :prompt_identifier,
  :prompt_version,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end

#prompt_versionString

The version of the prompt about which you want to retrieve information. Omit this field to return information about the working draft of the prompt.

Returns:

  • (String)


5555
5556
5557
5558
5559
5560
5561
# File 'lib/aws-sdk-bedrockagent/types.rb', line 5555

class GetPromptRequest < Struct.new(
  :prompt_identifier,
  :prompt_version,
  :included_data)
  SENSITIVE = []
  include Aws::Structure
end