Class: Aws::BedrockAgent::Types::InvalidLoopBoundaryFlowValidationDetails
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::InvalidLoopBoundaryFlowValidationDetails
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Details about a flow that contains connections that violate loop boundary rules.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection ⇒ String
The name of the connection that violates loop boundary rules.
-
#source ⇒ String
The source node of the connection that violates DoWhile loop boundary rules.
-
#target ⇒ String
The target node of the connection that violates DoWhile loop boundary rules.
Instance Attribute Details
#connection ⇒ String
The name of the connection that violates loop boundary rules.
6177 6178 6179 6180 6181 6182 6183 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6177 class InvalidLoopBoundaryFlowValidationDetails < Struct.new( :connection, :source, :target) SENSITIVE = [] include Aws::Structure end |
#source ⇒ String
The source node of the connection that violates DoWhile loop boundary rules.
6177 6178 6179 6180 6181 6182 6183 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6177 class InvalidLoopBoundaryFlowValidationDetails < Struct.new( :connection, :source, :target) SENSITIVE = [] include Aws::Structure end |
#target ⇒ String
The target node of the connection that violates DoWhile loop boundary rules.
6177 6178 6179 6180 6181 6182 6183 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6177 class InvalidLoopBoundaryFlowValidationDetails < Struct.new( :connection, :source, :target) SENSITIVE = [] include Aws::Structure end |