Class: Aws::BedrockAgent::Types::KnowledgeBaseConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains details about the vector embeddings configuration of the knowledge base.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#kendra_knowledge_base_configurationTypes::KendraKnowledgeBaseConfiguration

Settings for an Amazon Kendra knowledge base.



6321
6322
6323
6324
6325
6326
6327
6328
6329
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321

class KnowledgeBaseConfiguration < Struct.new(
  :type,
  :vector_knowledge_base_configuration,
  :managed_knowledge_base_configuration,
  :kendra_knowledge_base_configuration,
  :sql_knowledge_base_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#managed_knowledge_base_configurationTypes::ManagedKnowledgeBaseConfiguration

Configurations for a managed knowledge base.



6321
6322
6323
6324
6325
6326
6327
6328
6329
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321

class KnowledgeBaseConfiguration < Struct.new(
  :type,
  :vector_knowledge_base_configuration,
  :managed_knowledge_base_configuration,
  :kendra_knowledge_base_configuration,
  :sql_knowledge_base_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#sql_knowledge_base_configurationTypes::SqlKnowledgeBaseConfiguration

Specifies configurations for a knowledge base connected to an SQL database.



6321
6322
6323
6324
6325
6326
6327
6328
6329
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321

class KnowledgeBaseConfiguration < Struct.new(
  :type,
  :vector_knowledge_base_configuration,
  :managed_knowledge_base_configuration,
  :kendra_knowledge_base_configuration,
  :sql_knowledge_base_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

The type of data that the data source is converted into for the knowledge base. Choose ‘MANAGED` to create a managed knowledge base.

Returns:

  • (String)


6321
6322
6323
6324
6325
6326
6327
6328
6329
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321

class KnowledgeBaseConfiguration < Struct.new(
  :type,
  :vector_knowledge_base_configuration,
  :managed_knowledge_base_configuration,
  :kendra_knowledge_base_configuration,
  :sql_knowledge_base_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#vector_knowledge_base_configurationTypes::VectorKnowledgeBaseConfiguration

Contains details about the model that’s used to convert the data source into vector embeddings.



6321
6322
6323
6324
6325
6326
6327
6328
6329
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321

class KnowledgeBaseConfiguration < Struct.new(
  :type,
  :vector_knowledge_base_configuration,
  :managed_knowledge_base_configuration,
  :kendra_knowledge_base_configuration,
  :sql_knowledge_base_configuration)
  SENSITIVE = []
  include Aws::Structure
end