Class: Aws::BedrockAgent::Types::KnowledgeBaseConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::KnowledgeBaseConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about the vector embeddings configuration of the knowledge base.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#kendra_knowledge_base_configuration ⇒ Types::KendraKnowledgeBaseConfiguration
Settings for an Amazon Kendra knowledge base.
-
#managed_knowledge_base_configuration ⇒ Types::ManagedKnowledgeBaseConfiguration
Configurations for a managed knowledge base.
-
#sql_knowledge_base_configuration ⇒ Types::SqlKnowledgeBaseConfiguration
Specifies configurations for a knowledge base connected to an SQL database.
-
#type ⇒ String
The type of data that the data source is converted into for the knowledge base.
-
#vector_knowledge_base_configuration ⇒ Types::VectorKnowledgeBaseConfiguration
Contains details about the model that’s used to convert the data source into vector embeddings.
Instance Attribute Details
#kendra_knowledge_base_configuration ⇒ Types::KendraKnowledgeBaseConfiguration
Settings for an Amazon Kendra knowledge base.
6321 6322 6323 6324 6325 6326 6327 6328 6329 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |
#managed_knowledge_base_configuration ⇒ Types::ManagedKnowledgeBaseConfiguration
Configurations for a managed knowledge base.
6321 6322 6323 6324 6325 6326 6327 6328 6329 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |
#sql_knowledge_base_configuration ⇒ Types::SqlKnowledgeBaseConfiguration
Specifies configurations for a knowledge base connected to an SQL database.
6321 6322 6323 6324 6325 6326 6327 6328 6329 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
The type of data that the data source is converted into for the knowledge base. Choose ‘MANAGED` to create a managed knowledge base.
6321 6322 6323 6324 6325 6326 6327 6328 6329 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |
#vector_knowledge_base_configuration ⇒ Types::VectorKnowledgeBaseConfiguration
Contains details about the model that’s used to convert the data source into vector embeddings.
6321 6322 6323 6324 6325 6326 6327 6328 6329 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6321 class KnowledgeBaseConfiguration < Struct.new( :type, :vector_knowledge_base_configuration, :managed_knowledge_base_configuration, :kendra_knowledge_base_configuration, :sql_knowledge_base_configuration) SENSITIVE = [] include Aws::Structure end |