Class: Aws::BedrockAgent::Types::LambdaFunctionFlowNodeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::LambdaFunctionFlowNodeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains configurations for a Lambda function node in the flow. You specify the Lambda function to invoke and the inputs into the function. The output is the response that is defined in the Lambda function. For more information, see [Node types in a flow] in the Amazon Bedrock User Guide.
[1]: docs.aws.amazon.com/bedrock/latest/userguide/flows-nodes.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lambda_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function to invoke.
Instance Attribute Details
#lambda_arn ⇒ String
The Amazon Resource Name (ARN) of the Lambda function to invoke.
6586 6587 6588 6589 6590 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6586 class LambdaFunctionFlowNodeConfiguration < Struct.new( :lambda_arn) SENSITIVE = [] include Aws::Structure end |