Class: Aws::BedrockAgent::Types::ListDataSourcesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListDataSourcesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_summaries ⇒ Array<Types::DataSourceSummary>
A list of objects, each of which contains information about a data source.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, use this token when making another request in thenextTokenfield to return the next batch of results.
Instance Attribute Details
#data_source_summaries ⇒ Array<Types::DataSourceSummary>
A list of objects, each of which contains information about a data source.
7051 7052 7053 7054 7055 7056 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7051 class ListDataSourcesResponse < Struct.new( :data_source_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, use this token when making another
request in the nextToken field to return the next batch of
results.
7051 7052 7053 7054 7055 7056 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7051 class ListDataSourcesResponse < Struct.new( :data_source_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |