Class: Aws::BedrockAgent::Types::ListFlowAliasesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListFlowAliasesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_alias_summaries ⇒ Array<Types::FlowAliasSummary>
A list, each member of which contains information about an alias.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, use this token when making another request in thenextTokenfield to return the next batch of results.
Instance Attribute Details
#flow_alias_summaries ⇒ Array<Types::FlowAliasSummary>
A list, each member of which contains information about an alias.
7100 7101 7102 7103 7104 7105 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7100 class ListFlowAliasesResponse < Struct.new( :flow_alias_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, use this token when making another
request in the nextToken field to return the next batch of
results.
7100 7101 7102 7103 7104 7105 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7100 class ListFlowAliasesResponse < Struct.new( :flow_alias_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |