Class: Aws::BedrockAgent::Types::ListFlowVersionsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListFlowVersionsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_version_summaries ⇒ Array<Types::FlowVersionSummary>
A list, each member of which contains information about a flow.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, use this token when making another request in thenextTokenfield to return the next batch of results.
Instance Attribute Details
#flow_version_summaries ⇒ Array<Types::FlowVersionSummary>
A list, each member of which contains information about a flow.
7148 7149 7150 7151 7152 7153 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7148 class ListFlowVersionsResponse < Struct.new( :flow_version_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, use this token when making another
request in the nextToken field to return the next batch of
results.
7148 7149 7150 7151 7152 7153 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7148 class ListFlowVersionsResponse < Struct.new( :flow_version_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |