Class: Aws::BedrockAgent::Types::ListFlowsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListFlowsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#flow_summaries ⇒ Array<Types::FlowSummary>
A list, each member of which contains information about a flow.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, use this token when making another request in thenextTokenfield to return the next batch of results.
Instance Attribute Details
#flow_summaries ⇒ Array<Types::FlowSummary>
A list, each member of which contains information about a flow.
7191 7192 7193 7194 7195 7196 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7191 class ListFlowsResponse < Struct.new( :flow_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, use this token when making another
request in the nextToken field to return the next batch of
results.
7191 7192 7193 7194 7195 7196 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7191 class ListFlowsResponse < Struct.new( :flow_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |