Class: Aws::BedrockAgent::Types::ListKnowledgeBaseDocumentsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListKnowledgeBaseDocumentsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#data_source_id ⇒ String
The unique identifier of the data source that contains the documents.
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base that is connected to the data source.
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, enter the token returned in thenextTokenfield in the response in this field to return the next batch of results.
Instance Attribute Details
#data_source_id ⇒ String
The unique identifier of the data source that contains the documents.
7289 7290 7291 7292 7293 7294 7295 7296 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7289 class ListKnowledgeBaseDocumentsRequest < Struct.new( :knowledge_base_id, :data_source_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base that is connected to the data source.
7289 7290 7291 7292 7293 7294 7295 7296 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7289 class ListKnowledgeBaseDocumentsRequest < Struct.new( :knowledge_base_id, :data_source_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of results to return in the response. If the
total number of results is greater than this value, use the token
returned in the response in the nextToken field when making
another request to return the next batch of results.
7289 7290 7291 7292 7293 7294 7295 7296 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7289 class ListKnowledgeBaseDocumentsRequest < Struct.new( :knowledge_base_id, :data_source_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, enter the token returned in the
nextToken field in the response in this field to return the next
batch of results.
7289 7290 7291 7292 7293 7294 7295 7296 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7289 class ListKnowledgeBaseDocumentsRequest < Struct.new( :knowledge_base_id, :data_source_id, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |