Class: Aws::BedrockAgent::Types::ListKnowledgeBasesResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListKnowledgeBasesResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#knowledge_base_summaries ⇒ Array<Types::KnowledgeBaseSummary>
A list of knowledge bases with information about each knowledge base.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, use this token when making another request in thenextTokenfield to return the next batch of results.
Instance Attribute Details
#knowledge_base_summaries ⇒ Array<Types::KnowledgeBaseSummary>
A list of knowledge bases with information about each knowledge base.
7356 7357 7358 7359 7360 7361 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7356 class ListKnowledgeBasesResponse < Struct.new( :knowledge_base_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, use this token when making another
request in the nextToken field to return the next batch of
results.
7356 7357 7358 7359 7360 7361 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7356 class ListKnowledgeBasesResponse < Struct.new( :knowledge_base_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |