Class: Aws::BedrockAgent::Types::ListPromptsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListPromptsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#max_results ⇒ Integer
The maximum number of results to return in the response.
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, enter the token returned in thenextTokenfield in the response in this field to return the next batch of results. -
#prompt_identifier ⇒ String
The unique identifier of the prompt for whose versions you want to return information.
Instance Attribute Details
#max_results ⇒ Integer
The maximum number of results to return in the response. If the
total number of results is greater than this value, use the token
returned in the response in the nextToken field when making
another request to return the next batch of results.
7385 7386 7387 7388 7389 7390 7391 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7385 class ListPromptsRequest < Struct.new( :prompt_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, enter the token returned in the
nextToken field in the response in this field to return the next
batch of results.
7385 7386 7387 7388 7389 7390 7391 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7385 class ListPromptsRequest < Struct.new( :prompt_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |
#prompt_identifier ⇒ String
The unique identifier of the prompt for whose versions you want to return information. Omit this field to list information about all prompts in an account.
7385 7386 7387 7388 7389 7390 7391 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7385 class ListPromptsRequest < Struct.new( :prompt_identifier, :max_results, :next_token) SENSITIVE = [] include Aws::Structure end |