Class: Aws::BedrockAgent::Types::ListPromptsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::ListPromptsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_token ⇒ String
If the total number of results is greater than the
maxResultsvalue provided in the request, use this token when making another request in thenextTokenfield to return the next batch of results. -
#prompt_summaries ⇒ Array<Types::PromptSummary>
A list, each member of which contains information about a prompt using Prompt management.
Instance Attribute Details
#next_token ⇒ String
If the total number of results is greater than the maxResults
value provided in the request, use this token when making another
request in the nextToken field to return the next batch of
results.
7407 7408 7409 7410 7411 7412 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7407 class ListPromptsResponse < Struct.new( :prompt_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |
#prompt_summaries ⇒ Array<Types::PromptSummary>
A list, each member of which contains information about a prompt using Prompt management.
7407 7408 7409 7410 7411 7412 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7407 class ListPromptsResponse < Struct.new( :prompt_summaries, :next_token) SENSITIVE = [] include Aws::Structure end |