Class: Aws::BedrockAgent::Types::MetadataConfigurationForReranking

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Specifies how metadata fields should be handled during the reranking process.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#selection_modeString

The mode for selecting metadata fields for reranking.

Returns:

  • (String)


7707
7708
7709
7710
7711
7712
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7707

class MetadataConfigurationForReranking < Struct.new(
  :selection_mode,
  :selective_mode_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#selective_mode_configurationTypes::RerankingMetadataSelectiveModeConfiguration

The configuration for selective metadata field inclusion or exclusion during reranking.



7707
7708
7709
7710
7711
7712
# File 'lib/aws-sdk-bedrockagent/types.rb', line 7707

class MetadataConfigurationForReranking < Struct.new(
  :selection_mode,
  :selective_mode_configuration)
  SENSITIVE = []
  include Aws::Structure
end