Class: Aws::BedrockAgent::Types::OpenSearchServerlessFieldMapping
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::OpenSearchServerlessFieldMapping
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains the names of the fields to which to map information about the vector store.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#metadata_field ⇒ String
The name of the field in which Amazon Bedrock stores metadata about the vector store.
-
#text_field ⇒ String
The name of the field in which Amazon Bedrock stores the raw text from your data.
-
#vector_field ⇒ String
The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
Instance Attribute Details
#metadata_field ⇒ String
The name of the field in which Amazon Bedrock stores metadata about the vector store.
6737 6738 6739 6740 6741 6742 6743 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6737 class OpenSearchServerlessFieldMapping < Struct.new( :metadata_field, :text_field, :vector_field) SENSITIVE = [] include Aws::Structure end |
#text_field ⇒ String
The name of the field in which Amazon Bedrock stores the raw text from your data. The text is split according to the chunking strategy you choose.
6737 6738 6739 6740 6741 6742 6743 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6737 class OpenSearchServerlessFieldMapping < Struct.new( :metadata_field, :text_field, :vector_field) SENSITIVE = [] include Aws::Structure end |
#vector_field ⇒ String
The name of the field in which Amazon Bedrock stores the vector embeddings for your data sources.
6737 6738 6739 6740 6741 6742 6743 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 6737 class OpenSearchServerlessFieldMapping < Struct.new( :metadata_field, :text_field, :vector_field) SENSITIVE = [] include Aws::Structure end |