Class: Aws::BedrockAgent::Types::OrchestrationExecutor

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Note:

OrchestrationExecutor is a union - when making an API calls you must set exactly one of the members.

Note:

OrchestrationExecutor is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OrchestrationExecutor corresponding to the set member.

Contains details about the Lambda function containing the orchestration logic carried out upon invoking the custom orchestration.

Direct Known Subclasses

Lambda, Unknown

Defined Under Namespace

Classes: Lambda, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#lambdaString

The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action.

Returns:

  • (String)


8217
8218
8219
8220
8221
8222
8223
8224
8225
8226
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8217

class OrchestrationExecutor < Struct.new(
  :lambda,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Lambda < OrchestrationExecutor; end
  class Unknown < OrchestrationExecutor; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



8217
8218
8219
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8217

def unknown
  @unknown
end