Class: Aws::BedrockAgent::Types::OrchestrationExecutor
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::OrchestrationExecutor
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
OrchestrationExecutor is a union - when making an API calls you must set exactly one of the members.
OrchestrationExecutor is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of OrchestrationExecutor corresponding to the set member.
Contains details about the Lambda function containing the orchestration logic carried out upon invoking the custom orchestration.
Defined Under Namespace
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#lambda ⇒ String
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#lambda ⇒ String
The Amazon Resource Name (ARN) of the Lambda function containing the business logic that is carried out upon invoking the action.
8217 8218 8219 8220 8221 8222 8223 8224 8225 8226 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8217 class OrchestrationExecutor < Struct.new( :lambda, :unknown) SENSITIVE = [] include Aws::Structure include Aws::Structure::Union class Lambda < OrchestrationExecutor; end class Unknown < OrchestrationExecutor; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
8217 8218 8219 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8217 def unknown @unknown end |