Class: Aws::BedrockAgent::Types::ParsingConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Settings for parsing document contents. If you exclude this field, the default parser converts the contents of each document into text before splitting it into chunks. Specify the parsing strategy to use in the ‘parsingStrategy` field and include the relevant configuration, or omit it to use the Amazon Bedrock default parser. For more information, see [Parsing options for your data source].

<note markdown=“1”> If you specify ‘BEDROCK_DATA_AUTOMATION` or `BEDROCK_FOUNDATION_MODEL` and it fails to parse a file, the Amazon Bedrock default parser will be used instead.

</note>

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-advanced-parsing.html

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#bedrock_data_automation_configurationTypes::BedrockDataAutomationConfiguration

If you specify ‘BEDROCK_DATA_AUTOMATION` as the parsing strategy for ingesting your data source, use this object to modify configurations for using the Amazon Bedrock Data Automation parser.



8326
8327
8328
8329
8330
8331
8332
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8326

class ParsingConfiguration < Struct.new(
  :parsing_strategy,
  :bedrock_foundation_model_configuration,
  :bedrock_data_automation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#bedrock_foundation_model_configurationTypes::BedrockFoundationModelConfiguration

If you specify ‘BEDROCK_FOUNDATION_MODEL` as the parsing strategy for ingesting your data source, use this object to modify configurations for using a foundation model to parse documents.



8326
8327
8328
8329
8330
8331
8332
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8326

class ParsingConfiguration < Struct.new(
  :parsing_strategy,
  :bedrock_foundation_model_configuration,
  :bedrock_data_automation_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#parsing_strategyString

The parsing strategy for the data source. Only ‘SMART_PARSING` can be selected for managed knowledge bases. For more information, see [Customize ingestion for managed knowledge bases].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/kb-managed-customize-ingestion.html

Returns:

  • (String)


8326
8327
8328
8329
8330
8331
8332
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8326

class ParsingConfiguration < Struct.new(
  :parsing_strategy,
  :bedrock_foundation_model_configuration,
  :bedrock_data_automation_configuration)
  SENSITIVE = []
  include Aws::Structure
end