Class: Aws::BedrockAgent::Types::PineconeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::PineconeConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about the storage configuration of the knowledge base in Pinecone. For more information, see [Create a vector index in Pinecone].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/knowledge-base-setup-pinecone.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#connection_string ⇒ String
The endpoint URL for your index management page.
-
#credentials_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret that you created in Secrets Manager that is linked to your Pinecone API key.
-
#field_mapping ⇒ Types::PineconeFieldMapping
Contains the names of the fields to which to map information about the vector store.
-
#namespace ⇒ String
The namespace to be used to write new data to your database.
Instance Attribute Details
#connection_string ⇒ String
The endpoint URL for your index management page.
8440 8441 8442 8443 8444 8445 8446 8447 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8440 class PineconeConfiguration < Struct.new( :connection_string, :credentials_secret_arn, :namespace, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#credentials_secret_arn ⇒ String
The Amazon Resource Name (ARN) of the secret that you created in Secrets Manager that is linked to your Pinecone API key.
8440 8441 8442 8443 8444 8445 8446 8447 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8440 class PineconeConfiguration < Struct.new( :connection_string, :credentials_secret_arn, :namespace, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#field_mapping ⇒ Types::PineconeFieldMapping
Contains the names of the fields to which to map information about the vector store.
8440 8441 8442 8443 8444 8445 8446 8447 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8440 class PineconeConfiguration < Struct.new( :connection_string, :credentials_secret_arn, :namespace, :field_mapping) SENSITIVE = [] include Aws::Structure end |
#namespace ⇒ String
The namespace to be used to write new data to your database.
8440 8441 8442 8443 8444 8445 8446 8447 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8440 class PineconeConfiguration < Struct.new( :connection_string, :credentials_secret_arn, :namespace, :field_mapping) SENSITIVE = [] include Aws::Structure end |