Class: Aws::BedrockAgent::Types::PromptConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::PromptConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains configurations to override a prompt template in one part of an agent sequence. For more information, see [Advanced prompts].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts.html
Constant Summary collapse
- SENSITIVE =
[:base_prompt_template]
Instance Attribute Summary collapse
-
#additional_model_request_fields ⇒ Hash, ...
If the Converse or ConverseStream operations support the model, ‘additionalModelRequestFields` contains additional inference parameters, beyond the base set of inference parameters in the `inferenceConfiguration` field.
-
#base_prompt_template ⇒ String
Defines the prompt template with which to replace the default prompt template.
-
#foundation_model ⇒ String
The agent’s foundation model.
-
#inference_configuration ⇒ Types::InferenceConfiguration
Contains inference parameters to use when the agent invokes a foundation model in the part of the agent sequence defined by the ‘promptType`.
-
#parser_mode ⇒ String
Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the ‘promptType`.
-
#prompt_creation_mode ⇒ String
Specifies whether to override the default prompt template for this ‘promptType`.
-
#prompt_state ⇒ String
Specifies whether to allow the agent to carry out the step specified in the ‘promptType`.
-
#prompt_type ⇒ String
The step in the agent sequence that this prompt configuration applies to.
Instance Attribute Details
#additional_model_request_fields ⇒ Hash, ...
If the Converse or ConverseStream operations support the model, ‘additionalModelRequestFields` contains additional inference parameters, beyond the base set of inference parameters in the `inferenceConfiguration` field.
For more information, see *Inference request parameters and response fields for foundation models* in the Amazon Bedrock user guide.
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8654 class PromptConfiguration < Struct.new( :prompt_type, :prompt_creation_mode, :prompt_state, :base_prompt_template, :inference_configuration, :parser_mode, :foundation_model, :additional_model_request_fields) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#base_prompt_template ⇒ String
Defines the prompt template with which to replace the default prompt template. You can use placeholder variables in the base prompt template to customize the prompt. For more information, see [Prompt template placeholder variables]. For more information, see [Configure the prompt templates].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/prompt-placeholders.html [2]: docs.aws.amazon.com/bedrock/latest/userguide/advanced-prompts-configure.html
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8654 class PromptConfiguration < Struct.new( :prompt_type, :prompt_creation_mode, :prompt_state, :base_prompt_template, :inference_configuration, :parser_mode, :foundation_model, :additional_model_request_fields) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#foundation_model ⇒ String
The agent’s foundation model.
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8654 class PromptConfiguration < Struct.new( :prompt_type, :prompt_creation_mode, :prompt_state, :base_prompt_template, :inference_configuration, :parser_mode, :foundation_model, :additional_model_request_fields) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#inference_configuration ⇒ Types::InferenceConfiguration
Contains inference parameters to use when the agent invokes a foundation model in the part of the agent sequence defined by the ‘promptType`. For more information, see [Inference parameters for foundation models].
[1]: docs.aws.amazon.com/bedrock/latest/userguide/model-parameters.html
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8654 class PromptConfiguration < Struct.new( :prompt_type, :prompt_creation_mode, :prompt_state, :base_prompt_template, :inference_configuration, :parser_mode, :foundation_model, :additional_model_request_fields) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#parser_mode ⇒ String
Specifies whether to override the default parser Lambda function when parsing the raw foundation model output in the part of the agent sequence defined by the ‘promptType`. If you set the field as `OVERRIDDEN`, the `overrideLambda` field in the
- PromptOverrideConfiguration][1
-
must be specified with the ARN of a
Lambda function.
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent_PromptOverrideConfiguration.html
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8654 class PromptConfiguration < Struct.new( :prompt_type, :prompt_creation_mode, :prompt_state, :base_prompt_template, :inference_configuration, :parser_mode, :foundation_model, :additional_model_request_fields) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#prompt_creation_mode ⇒ String
Specifies whether to override the default prompt template for this ‘promptType`. Set this value to `OVERRIDDEN` to use the prompt that you provide in the `basePromptTemplate`. If you leave it as `DEFAULT`, the agent uses a default prompt template.
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8654 class PromptConfiguration < Struct.new( :prompt_type, :prompt_creation_mode, :prompt_state, :base_prompt_template, :inference_configuration, :parser_mode, :foundation_model, :additional_model_request_fields) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#prompt_state ⇒ String
Specifies whether to allow the agent to carry out the step specified in the ‘promptType`. If you set this value to `DISABLED`, the agent skips that step. The default state for each `promptType` is as follows.
-
‘PRE_PROCESSING` – `DISABLED`
-
‘ORCHESTRATION` – `ENABLED`
-
‘KNOWLEDGE_BASE_RESPONSE_GENERATION` – `ENABLED`
-
‘POST_PROCESSING` – `DISABLED`
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8654 class PromptConfiguration < Struct.new( :prompt_type, :prompt_creation_mode, :prompt_state, :base_prompt_template, :inference_configuration, :parser_mode, :foundation_model, :additional_model_request_fields) SENSITIVE = [:base_prompt_template] include Aws::Structure end |
#prompt_type ⇒ String
The step in the agent sequence that this prompt configuration applies to.
8654 8655 8656 8657 8658 8659 8660 8661 8662 8663 8664 8665 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 8654 class PromptConfiguration < Struct.new( :prompt_type, :prompt_creation_mode, :prompt_state, :base_prompt_template, :inference_configuration, :parser_mode, :foundation_model, :additional_model_request_fields) SENSITIVE = [:base_prompt_template] include Aws::Structure end |