Class: Aws::BedrockAgent::Types::PutResourcePolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::PutResourcePolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#expected_revision_id ⇒ String
The expected revision identifier of the resource policy.
-
#policy ⇒ String
The JSON-formatted resource policy to associate with the knowledge base.
-
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base to attach the resource policy to.
Instance Attribute Details
#expected_revision_id ⇒ String
The expected revision identifier of the resource policy. Use this to prevent conflicts when multiple users update the same policy concurrently. Specify the ‘revisionId` from the most recent `GetResourcePolicy` or `PutResourcePolicy` response.
9122 9123 9124 9125 9126 9127 9128 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9122 class PutResourcePolicyRequest < Struct.new( :resource_arn, :policy, :expected_revision_id) SENSITIVE = [] include Aws::Structure end |
#policy ⇒ String
The JSON-formatted resource policy to associate with the knowledge base.
9122 9123 9124 9125 9126 9127 9128 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9122 class PutResourcePolicyRequest < Struct.new( :resource_arn, :policy, :expected_revision_id) SENSITIVE = [] include Aws::Structure end |
#resource_arn ⇒ String
The Amazon Resource Name (ARN) of the knowledge base to attach the resource policy to.
9122 9123 9124 9125 9126 9127 9128 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9122 class PutResourcePolicyRequest < Struct.new( :resource_arn, :policy, :expected_revision_id) SENSITIVE = [] include Aws::Structure end |