Class: Aws::BedrockAgent::Types::QueryGenerationTable
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::QueryGenerationTable
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains information about a table for the query engine to consider.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#columns ⇒ Array<Types::QueryGenerationColumn>
An array of objects, each of which defines information about a column in the table.
-
#description ⇒ String
A description of the table that helps the query engine understand the contents of the table.
-
#inclusion ⇒ String
Specifies whether to include or exclude the table during query generation.
-
#name ⇒ String
The name of the table for which the other fields in this object apply.
Instance Attribute Details
#columns ⇒ Array<Types::QueryGenerationColumn>
An array of objects, each of which defines information about a column in the table.
9273 9274 9275 9276 9277 9278 9279 9280 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9273 class QueryGenerationTable < Struct.new( :name, :description, :inclusion, :columns) SENSITIVE = [] include Aws::Structure end |
#description ⇒ String
A description of the table that helps the query engine understand the contents of the table.
9273 9274 9275 9276 9277 9278 9279 9280 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9273 class QueryGenerationTable < Struct.new( :name, :description, :inclusion, :columns) SENSITIVE = [] include Aws::Structure end |
#inclusion ⇒ String
Specifies whether to include or exclude the table during query
generation. If you specify EXCLUDE, the table will be ignored. If
you specify INCLUDE, all other tables will be ignored.
9273 9274 9275 9276 9277 9278 9279 9280 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9273 class QueryGenerationTable < Struct.new( :name, :description, :inclusion, :columns) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
The name of the table for which the other fields in this object apply.
9273 9274 9275 9276 9277 9278 9279 9280 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9273 class QueryGenerationTable < Struct.new( :name, :description, :inclusion, :columns) SENSITIVE = [] include Aws::Structure end |