Class: Aws::BedrockAgent::Types::RerankingMetadataSelectiveModeConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Note:

RerankingMetadataSelectiveModeConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

RerankingMetadataSelectiveModeConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RerankingMetadataSelectiveModeConfiguration corresponding to the set member.

Configures the metadata fields to include or exclude during the reranking process when using selective mode.

Direct Known Subclasses

FieldsToExclude, FieldsToInclude, Unknown

Defined Under Namespace

Classes: FieldsToExclude, FieldsToInclude, Unknown

Constant Summary collapse

SENSITIVE =
[:fields_to_include, :fields_to_exclude]

Instance Attribute Summary collapse

Instance Attribute Details

#fields_to_excludeArray<Types::FieldForReranking>

Specifies the metadata fields to exclude from the reranking process.

Returns:



9663
9664
9665
9666
9667
9668
9669
9670
9671
9672
9673
9674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9663

class RerankingMetadataSelectiveModeConfiguration < Struct.new(
  :fields_to_include,
  :fields_to_exclude,
  :unknown)
  SENSITIVE = [:fields_to_include, :fields_to_exclude]
  include Aws::Structure
  include Aws::Structure::Union

  class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end
  class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end
  class Unknown < RerankingMetadataSelectiveModeConfiguration; end
end

#fields_to_includeArray<Types::FieldForReranking>

Specifies the metadata fields to include in the reranking process.

Returns:



9663
9664
9665
9666
9667
9668
9669
9670
9671
9672
9673
9674
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9663

class RerankingMetadataSelectiveModeConfiguration < Struct.new(
  :fields_to_include,
  :fields_to_exclude,
  :unknown)
  SENSITIVE = [:fields_to_include, :fields_to_exclude]
  include Aws::Structure
  include Aws::Structure::Union

  class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end
  class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end
  class Unknown < RerankingMetadataSelectiveModeConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



9663
9664
9665
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9663

def unknown
  @unknown
end