Class: Aws::BedrockAgent::Types::RerankingMetadataSelectiveModeConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::RerankingMetadataSelectiveModeConfiguration
- Includes:
- Structure, Structure::Union
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
RerankingMetadataSelectiveModeConfiguration is a union - when making an API calls you must set exactly one of the members.
RerankingMetadataSelectiveModeConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of RerankingMetadataSelectiveModeConfiguration corresponding to the set member.
Configures the metadata fields to include or exclude during the reranking process when using selective mode.
Direct Known Subclasses
Defined Under Namespace
Classes: FieldsToExclude, FieldsToInclude, Unknown
Constant Summary collapse
- SENSITIVE =
[:fields_to_include, :fields_to_exclude]
Instance Attribute Summary collapse
-
#fields_to_exclude ⇒ Array<Types::FieldForReranking>
Specifies the metadata fields to exclude from the reranking process.
-
#fields_to_include ⇒ Array<Types::FieldForReranking>
Specifies the metadata fields to include in the reranking process.
-
#unknown ⇒ Object
Returns the value of attribute unknown.
Instance Attribute Details
#fields_to_exclude ⇒ Array<Types::FieldForReranking>
Specifies the metadata fields to exclude from the reranking process.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9642 class RerankingMetadataSelectiveModeConfiguration < Struct.new( :fields_to_include, :fields_to_exclude, :unknown) SENSITIVE = [:fields_to_include, :fields_to_exclude] include Aws::Structure include Aws::Structure::Union class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end class Unknown < RerankingMetadataSelectiveModeConfiguration; end end |
#fields_to_include ⇒ Array<Types::FieldForReranking>
Specifies the metadata fields to include in the reranking process.
9642 9643 9644 9645 9646 9647 9648 9649 9650 9651 9652 9653 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9642 class RerankingMetadataSelectiveModeConfiguration < Struct.new( :fields_to_include, :fields_to_exclude, :unknown) SENSITIVE = [:fields_to_include, :fields_to_exclude] include Aws::Structure include Aws::Structure::Union class FieldsToInclude < RerankingMetadataSelectiveModeConfiguration; end class FieldsToExclude < RerankingMetadataSelectiveModeConfiguration; end class Unknown < RerankingMetadataSelectiveModeConfiguration; end end |
#unknown ⇒ Object
Returns the value of attribute unknown
9642 9643 9644 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9642 def unknown @unknown end |