Class: Aws::BedrockAgent::Types::StorageFlowNodeServiceConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Note:

StorageFlowNodeServiceConfiguration is a union - when making an API calls you must set exactly one of the members.

Note:

StorageFlowNodeServiceConfiguration is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of StorageFlowNodeServiceConfiguration corresponding to the set member.

Contains configurations for the service to use for storing the input into the node.

Direct Known Subclasses

S3, Unknown

Defined Under Namespace

Classes: S3, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#s3Types::StorageFlowNodeS3Configuration

Contains configurations for the Amazon S3 location in which to store the input into the node.



10382
10383
10384
10385
10386
10387
10388
10389
10390
10391
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10382

class StorageFlowNodeServiceConfiguration < Struct.new(
  :s3,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class S3 < StorageFlowNodeServiceConfiguration; end
  class Unknown < StorageFlowNodeServiceConfiguration; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



10382
10383
10384
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10382

def unknown
  @unknown
end