Class: Aws::BedrockAgent::Types::SupplementalDataStorageConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Specifies configurations for the storage location of multimedia content (images, audio, and video) extracted from multimodal documents in your data source. This content can be retrieved and returned to the end user with timestamp references for audio and video segments.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#storage_locationsArray<Types::SupplementalDataStorageLocation>

A list of objects specifying storage locations for multimedia content (images, audio, and video) extracted from multimodal documents in your data source.



10385
10386
10387
10388
10389
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10385

class SupplementalDataStorageConfiguration < Struct.new(
  :storage_locations)
  SENSITIVE = []
  include Aws::Structure
end