Class: Aws::BedrockAgent::Types::ToolChoice

Inherits:
Struct
  • Object
show all
Includes:
Structure, Structure::Union
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Note:

ToolChoice is a union - when making an API calls you must set exactly one of the members.

Note:

ToolChoice is a union - when returned from an API call exactly one value will be set and the returned type will be a subclass of ToolChoice corresponding to the set member.

Defines which tools the model should request when invoked. For more information, see [Use a tool to complete an Amazon Bedrock model response].

[1]: docs.aws.amazon.com/bedrock/latest/userguide/tool-use.html

Direct Known Subclasses

Any, Auto, Tool, Unknown

Defined Under Namespace

Classes: Any, Auto, Tool, Unknown

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#anyTypes::AnyToolChoice

Defines tools, at least one of which must be requested by the model. No text is generated but the results of tool use are sent back to the model to help generate a response.



10588
10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10588

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#autoTypes::AutoToolChoice

Defines tools. The model automatically decides whether to call a tool or to generate text instead.



10588
10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10588

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#toolTypes::SpecificToolChoice

Defines a specific tool that the model must request. No text is generated but the results of tool use are sent back to the model to help generate a response.



10588
10589
10590
10591
10592
10593
10594
10595
10596
10597
10598
10599
10600
10601
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10588

class ToolChoice < Struct.new(
  :auto,
  :any,
  :tool,
  :unknown)
  SENSITIVE = []
  include Aws::Structure
  include Aws::Structure::Union

  class Auto < ToolChoice; end
  class Any < ToolChoice; end
  class Tool < ToolChoice; end
  class Unknown < ToolChoice; end
end

#unknownObject

Returns the value of attribute unknown

Returns:

  • (Object)

    the current value of unknown



10588
10589
10590
# File 'lib/aws-sdk-bedrockagent/types.rb', line 10588

def unknown
  @unknown
end