Class: Aws::BedrockAgent::Types::UpdateKnowledgeBaseRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#descriptionString

Specifies a new description for the knowledge base.

Returns:

  • (String)


11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11693

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_configurationTypes::KnowledgeBaseConfiguration

Specifies the configuration for the embeddings model used for the knowledge base. You must use the same configuration as when the knowledge base was created.



11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11693

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#knowledge_base_idString

The unique identifier of the knowledge base to update.

Returns:

  • (String)


11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11693

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Specifies a new name for the knowledge base.

Returns:

  • (String)


11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11693

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#role_arnString

Specifies a different Amazon Resource Name (ARN) of the IAM role with permissions to invoke API operations on the knowledge base.

Returns:

  • (String)


11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11693

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#storage_configurationTypes::StorageConfiguration

Specifies the configuration for the vector store used for the knowledge base. You must use the same configuration as when the knowledge base was created.



11693
11694
11695
11696
11697
11698
11699
11700
11701
11702
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11693

class UpdateKnowledgeBaseRequest < Struct.new(
  :knowledge_base_id,
  :name,
  :description,
  :role_arn,
  :knowledge_base_configuration,
  :storage_configuration)
  SENSITIVE = []
  include Aws::Structure
end