Class: Aws::BedrockAgent::Types::UpdateKnowledgeBaseRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::UpdateKnowledgeBaseRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#description ⇒ String
Specifies a new description for the knowledge base.
-
#knowledge_base_configuration ⇒ Types::KnowledgeBaseConfiguration
Specifies the configuration for the embeddings model used for the knowledge base.
-
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base to update.
-
#name ⇒ String
Specifies a new name for the knowledge base.
-
#role_arn ⇒ String
Specifies a different Amazon Resource Name (ARN) of the IAM role with permissions to invoke API operations on the knowledge base.
-
#storage_configuration ⇒ Types::StorageConfiguration
Specifies the configuration for the vector store used for the knowledge base.
Instance Attribute Details
#description ⇒ String
Specifies a new description for the knowledge base.
11838 11839 11840 11841 11842 11843 11844 11845 11846 11847 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838 class UpdateKnowledgeBaseRequest < Struct.new( :knowledge_base_id, :name, :description, :role_arn, :knowledge_base_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_configuration ⇒ Types::KnowledgeBaseConfiguration
Specifies the configuration for the embeddings model used for the knowledge base. You must use the same configuration as when the knowledge base was created.
11838 11839 11840 11841 11842 11843 11844 11845 11846 11847 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838 class UpdateKnowledgeBaseRequest < Struct.new( :knowledge_base_id, :name, :description, :role_arn, :knowledge_base_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#knowledge_base_id ⇒ String
The unique identifier of the knowledge base to update.
11838 11839 11840 11841 11842 11843 11844 11845 11846 11847 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838 class UpdateKnowledgeBaseRequest < Struct.new( :knowledge_base_id, :name, :description, :role_arn, :knowledge_base_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Specifies a new name for the knowledge base.
11838 11839 11840 11841 11842 11843 11844 11845 11846 11847 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838 class UpdateKnowledgeBaseRequest < Struct.new( :knowledge_base_id, :name, :description, :role_arn, :knowledge_base_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#role_arn ⇒ String
Specifies a different Amazon Resource Name (ARN) of the IAM role with permissions to invoke API operations on the knowledge base.
11838 11839 11840 11841 11842 11843 11844 11845 11846 11847 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838 class UpdateKnowledgeBaseRequest < Struct.new( :knowledge_base_id, :name, :description, :role_arn, :knowledge_base_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |
#storage_configuration ⇒ Types::StorageConfiguration
Specifies the configuration for the vector store used for the knowledge base. You must use the same configuration as when the knowledge base was created.
11838 11839 11840 11841 11842 11843 11844 11845 11846 11847 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11838 class UpdateKnowledgeBaseRequest < Struct.new( :knowledge_base_id, :name, :description, :role_arn, :knowledge_base_configuration, :storage_configuration) SENSITIVE = [] include Aws::Structure end |