Class: Aws::BedrockAgent::Types::VectorKnowledgeBaseConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::VectorKnowledgeBaseConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
Contains details about the model used to create vector embeddings for the knowledge base.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#embedding_model_arn ⇒ String
The Amazon Resource Name (ARN) of the model used to create vector embeddings for the knowledge base.
-
#embedding_model_configuration ⇒ Types::EmbeddingModelConfiguration
The embeddings model configuration details for the vector model used in Knowledge Base.
-
#supplemental_data_storage_configuration ⇒ Types::SupplementalDataStorageConfiguration
If you include multimodal data from your data source, use this object to specify configurations for the storage location of the images extracted from your documents.
Instance Attribute Details
#embedding_model_arn ⇒ String
The Amazon Resource Name (ARN) of the model used to create vector embeddings for the knowledge base.
11588 11589 11590 11591 11592 11593 11594 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11588 class VectorKnowledgeBaseConfiguration < Struct.new( :embedding_model_arn, :embedding_model_configuration, :supplemental_data_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#embedding_model_configuration ⇒ Types::EmbeddingModelConfiguration
The embeddings model configuration details for the vector model used in Knowledge Base.
11588 11589 11590 11591 11592 11593 11594 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11588 class VectorKnowledgeBaseConfiguration < Struct.new( :embedding_model_arn, :embedding_model_configuration, :supplemental_data_storage_configuration) SENSITIVE = [] include Aws::Structure end |
#supplemental_data_storage_configuration ⇒ Types::SupplementalDataStorageConfiguration
If you include multimodal data from your data source, use this object to specify configurations for the storage location of the images extracted from your documents. These images can be retrieved and returned to the end user. They can also be used in generation when using [RetrieveAndGenerate].
[1]: docs.aws.amazon.com/bedrock/latest/APIReference/API_agent-runtime_RetrieveAndGenerate.html
11588 11589 11590 11591 11592 11593 11594 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 11588 class VectorKnowledgeBaseConfiguration < Struct.new( :embedding_model_arn, :embedding_model_configuration, :supplemental_data_storage_configuration) SENSITIVE = [] include Aws::Structure end |