Class: Aws::BedrockAgent::Types::VectorKnowledgeBaseConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

Contains details about the model used to create vector embeddings for the knowledge base.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#embedding_model_arnString

The Amazon Resource Name (ARN) of the model or inference profile used to create vector embeddings for the knowledge base.

Returns:

  • (String)


9689
9690
9691
9692
9693
9694
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9689

class VectorKnowledgeBaseConfiguration < Struct.new(
  :embedding_model_arn,
  :embedding_model_configuration)
  SENSITIVE = []
  include Aws::Structure
end

#embedding_model_configurationTypes::EmbeddingModelConfiguration

The embeddings model configuration details for the vector model used in Knowledge Base.



9689
9690
9691
9692
9693
9694
# File 'lib/aws-sdk-bedrockagent/types.rb', line 9689

class VectorKnowledgeBaseConfiguration < Struct.new(
  :embedding_model_arn,
  :embedding_model_configuration)
  SENSITIVE = []
  include Aws::Structure
end