Class: Aws::BedrockAgent::Types::WebCrawlerLimits

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-bedrockagent/types.rb

Overview

The rate limits for the URLs that you want to crawl. You should be authorized to crawl the URLs.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#max_pagesInteger

The max number of web pages crawled from your source URLs, up to 25,000 pages. If the web pages exceed this limit, the data source sync will fail and no web pages will be ingested.

Returns:

  • (Integer)


12142
12143
12144
12145
12146
12147
# File 'lib/aws-sdk-bedrockagent/types.rb', line 12142

class WebCrawlerLimits < Struct.new(
  :rate_limit,
  :max_pages)
  SENSITIVE = []
  include Aws::Structure
end

#rate_limitInteger

The max rate at which pages are crawled, up to 300 per minute per host.

Returns:

  • (Integer)


12142
12143
12144
12145
12146
12147
# File 'lib/aws-sdk-bedrockagent/types.rb', line 12142

class WebCrawlerLimits < Struct.new(
  :rate_limit,
  :max_pages)
  SENSITIVE = []
  include Aws::Structure
end