Class: Aws::BedrockAgent::Types::WeeklySchedule
- Inherits:
-
Struct
- Object
- Struct
- Aws::BedrockAgent::Types::WeeklySchedule
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-bedrockagent/types.rb
Overview
A weekly sync on a specified day of the week.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#day_of_week ⇒ String
The day of the week on which the weekly sync runs.
Instance Attribute Details
#day_of_week ⇒ String
The day of the week on which the weekly sync runs.
12357 12358 12359 12360 12361 |
# File 'lib/aws-sdk-bedrockagent/types.rb', line 12357 class WeeklySchedule < Struct.new( :day_of_week) SENSITIVE = [] include Aws::Structure end |